/**
 * Parameters for constructing an {@link InvalidBytesSizeError}.
 * @typedef {Object} InvalidBytesSizeErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {InternalError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the size of the bytes does not match the expected size.
 *
 * @example
 * ```javascript
 * import { InvalidBytesSizeError } from '@tevm/errors'
 * import { hexToBytes } from '@tevm/utils'
 *
 * function requireBytes32(value) {
 *   const bytes = hexToBytes(value)
 *   if (bytes.length !== 32) {
 *     throw new InvalidBytesSizeError(bytes.length, 32)
 *   }
 *   return bytes
 * }
 *
 * try {
 *   requireBytes32('0x1234') // This will throw an InvalidBytesSizeError
 * } catch (error) {
 *   if (error instanceof InvalidBytesSizeError) {
 *     console.error(`Invalid bytes size: ${error.message}`)
 *     console.log(`Actual size: ${error.size}, Expected size: ${error.expectedSize}`)
 *   }
 * }
 * ```
 *
 * @extends {InternalError}
 */
export class InvalidBytesSizeError extends InternalError {
    /**
     * Constructs an InvalidBytesSizeError.
     *
     * @param {number} size - The actual size of the bytes.
     * @param {number} expectedSize - The expected size of the bytes.
     * @param {string} [message] - Human-readable error message.
     * @param {InvalidBytesSizeErrorParameters} [args] - Additional parameters for the error.
     */
    constructor(size: number, expectedSize: number, message?: string, args?: InvalidBytesSizeErrorParameters);
    /**
     * The actual size of the bytes.
     * @type {number}
     */
    size: number;
    /**
     * The expected size of the bytes.
     * @type {number}
     */
    expectedSize: number;
}
/**
 * Parameters for constructing an {@link InvalidBytesSizeError}.
 */
export type InvalidBytesSizeErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: InternalError | import("@ethereumjs/evm").EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};
import { InternalError } from '../ethereum/InternalErrorError.js';
//# sourceMappingURL=InvalidByteSizeError.d.ts.map