/**
 * Parameters for constructing a {@link DefensiveNullCheckError}.
 * @typedef {Object} DefensiveNullCheckErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {InternalError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when a defensive null check is tripped.
 * This error should never be thrown and indicates a bug in the Tevm VM if it is thrown.
 *
 * @example
 * ```javascript
 * import { DefensiveNullCheckError } from '@tevm/errors'
 *
 * function assertNotNull(value, message) {
 *   if (value === null || value === undefined) {
 *     throw new DefensiveNullCheckError(message)
 *   }
 *   return value
 * }
 *
 * try {
 *   const result = someFunction()
 *   assertNotNull(result, 'Result should not be null')
 * } catch (error) {
 *   if (error instanceof DefensiveNullCheckError) {
 *     console.error('Unexpected null value:', error.message)
 *     // This indicates a bug in the Tevm VM
 *     reportBugToTevmRepository(error)
 *   }
 * }
 * ```
 *
 * @extends {InternalError}
 */
export class DefensiveNullCheckError extends InternalError {
    /**
     * Constructs a DefensiveNullCheckError.
     *
     * @param {string} [message] - Human-readable error message.
     * @param {DefensiveNullCheckErrorParameters} [args] - Additional parameters for the error.
     */
    constructor(message?: string, args?: DefensiveNullCheckErrorParameters);
}
/**
 * Parameters for constructing a {@link DefensiveNullCheckError}.
 */
export type DefensiveNullCheckErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: InternalError | import("@ethereumjs/evm").EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};
import { InternalError } from '../ethereum/InternalErrorError.js';
//# sourceMappingURL=DefensiveNullCheckError.d.ts.map