/**
 * @typedef {Object} BaseErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error|import('@ethereumjs/evm').EVMError|unknown} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 */
/**
 * @typedef {Object} BaseErrorType
 * @property {string} _tag - Internal tag for the error.
 * @property {string} name - The name of the error.
 * @property {string} message - Human-readable error message.
 * @property {string} details - Details of the error.
 * @property {string|undefined} [docsPath] - Path to the documentation for this error.
 * @property {string} shortMessage - Short message describing the error.
 * @property {string} version - The version of the library.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {Function} walk - Function to walk through the error chain.
 */
/**
 * Base class for custom errors in TEVM.
 * This class is abstract and should be extended by other error classes.
 * @abstract
 * @extends {Error}
 * @implements {BaseErrorType}
 */
export class BaseError extends Error implements BaseErrorType {
    /**
     * @param {string} shortMessage - A short, human-readable summary of the error.
     * @param {BaseErrorParameters} args={} - Additional parameters for the error.
     * @param {string} _tag - Internal tag for the error.
     * @param {number} [code] - Error code analogous to the code in JSON RPC error.
     */
    constructor(shortMessage: string, args: BaseErrorParameters, _tag: string, code?: number);
    /**
     * @type {string}
     */
    _tag: string;
    /**
     * @type {string}
     */
    details: string;
    /**
     * @type {string|undefined}
     */
    docsPath: string | undefined;
    /**
     * @type {string[]|undefined}
     */
    metaMessages: string[] | undefined;
    /**
     * @type {string}
     */
    shortMessage: string;
    /**
     * @type {string}
     */
    version: string;
    /**
     * @type {number}
     */
    code: number;
    cause: any;
    /**
     * Walks through the error chain.
     * @param {Function} [fn] - A function to execute on each error in the chain.
     * @returns {Error|unknown} The first error that matches the function, or the original error.
     */
    walk(fn?: Function): Error | unknown;
}
export type BaseErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error | import("@ethereumjs/evm").EVMError | unknown;
    /**
     * - Details of the error.
     */
    details?: string;
};
export type BaseErrorType = {
    /**
     * - Internal tag for the error.
     */
    _tag: string;
    /**
     * - The name of the error.
     */
    name: string;
    /**
     * - Human-readable error message.
     */
    message: string;
    /**
     * - Details of the error.
     */
    details: string;
    /**
     * - Path to the documentation for this error.
     */
    docsPath?: string | undefined;
    /**
     * - Short message describing the error.
     */
    shortMessage: string;
    /**
     * - The version of the library.
     */
    version: string;
    /**
     * - Error code, analogous to the code in JSON RPC error.
     */
    code: number;
    /**
     * - Function to walk through the error chain.
     */
    walk: Function;
};
//# sourceMappingURL=BaseError.d.ts.map