/**
 * Parameters for constructing an InsufficientFundsError.
 * @typedef {Object} InsufficientFundsErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when there are insufficient funds for a transaction.
 *
 * This error is typically encountered when a transaction is attempted with a balance that is too low to cover the transaction cost.
 *
 * @example
 * try {
 *   // Some operation that can throw an InsufficientFundsError
 * } catch (error) {
 *   if (error instanceof InsufficientFundsError) {
 *     console.error(error.message);
 *     // Handle the insufficient funds error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InsufficientFundsErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InsufficientFunds'} _tag - Same as name, used internally.
 * @property {'InsufficientFunds'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
export class InsufficientFundsError extends BaseError {
    /**
     * Constructs an InsufficientFundsError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InsufficientFundsErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InsufficientFunds'] - The tag for the error.
     */
    constructor(message: string, args?: InsufficientFundsErrorParameters, tag?: string);
}
/**
 * Parameters for constructing an InsufficientFundsError.
 */
export type InsufficientFundsErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};
import { BaseError } from './BaseError.js';
//# sourceMappingURL=InsufficientFundsError.d.ts.map