/**
 * Parameters for constructing an InvalidBalanceError.
 * @typedef {Object} InvalidBalanceErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when an account balance is invalid.
 *
 * This error is typically encountered when setting or manipulating account balances with invalid values.
 *
 * @example
 * ```javascript
 * import { InvalidBalanceError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.setAccount({
 *     address: '0x...',
 *     balance: -1000n, // Invalid negative balance
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidBalanceError) {
 *     console.error('Invalid balance:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
export class InvalidBalanceError extends InvalidParamsError {
    /**
     * Constructs an InvalidBalanceError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidBalanceErrorParameters} [args={}] - Additional parameters for the InvalidBalanceError.
     */
    constructor(message: string, args?: InvalidBalanceErrorParameters);
}
/**
 * Parameters for constructing an InvalidBalanceError.
 */
export type InvalidBalanceErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: import("../ethereum/BaseError.js").BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};
import { InvalidParamsError } from '../ethereum/InvalidParamsError.js';
//# sourceMappingURL=InvalidBalanceError.d.ts.map