/**
 * Parameters for constructing an InvalidBlobVersionedHashesError.
 * @typedef {Object} InvalidBlobVersionedHashesErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the blobVersionedHashes parameter is invalid.
 *
 * This error is typically encountered when a transaction or operation references a blobVersionedHashes parameter that is malformed or does not conform to the expected structure.
 *
 * @example
 * ```javascript
 * import { InvalidBlobVersionedHashesError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.sendTransaction({
 *     // ... other transaction parameters
 *     blobVersionedHashes: ['invalid_hash'], // This should be a valid versioned hash
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidBlobVersionedHashesError) {
 *     console.error('Invalid blob versioned hashes:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
export class InvalidBlobVersionedHashesError extends InvalidParamsError {
    /**
     * Constructs an InvalidBlobVersionedHashesError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidBlobVersionedHashesErrorParameters} [args={}] - Additional parameters for the InvalidBlobVersionedHashesError.
     */
    constructor(message: string, args?: InvalidBlobVersionedHashesErrorParameters);
}
/**
 * Parameters for constructing an InvalidBlobVersionedHashesError.
 */
export type InvalidBlobVersionedHashesErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: import("../ethereum/BaseError.js").BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};
import { InvalidParamsError } from '../ethereum/InvalidParamsError.js';
//# sourceMappingURL=InvalidBlobVersionedHashesError.d.ts.map