/**
 * Parameters for constructing an InvalidGasRefundError.
 * @typedef {Object} InvalidGasRefundErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the gas refund is invalid.
 *
 * This error is typically encountered when a transaction or operation specifies an invalid gas refund value.
 *
 * @example
 * ```javascript
 * import { InvalidGasRefundError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.setAccount({
 *     address: '0x1234567890123456789012345678901234567890',
 *     gasRefund: -1n, // Invalid negative gas refund
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidGasRefundError) {
 *     console.error('Invalid gas refund:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
export class InvalidGasRefundError extends InvalidParamsError {
    /**
     * Constructs an InvalidGasRefundError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidGasRefundErrorParameters} [args={}] - Additional parameters for the InvalidGasRefundError.
     */
    constructor(message: string, args?: InvalidGasRefundErrorParameters);
}
/**
 * Parameters for constructing an InvalidGasRefundError.
 */
export type InvalidGasRefundErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: import("../ethereum/BaseError.js").BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};
import { InvalidParamsError } from '../ethereum/InvalidParamsError.js';
//# sourceMappingURL=InvalidGasRefundError.d.ts.map