import * as _ethereumjs_evm from '@ethereumjs/evm';
export { InternalRpcError, InvalidInputRpcError, InvalidParamsRpcError, InvalidRequestRpcError, JsonRpcVersionUnsupportedError, LimitExceededRpcError, MethodNotFoundRpcError, MethodNotSupportedRpcError, ParseRpcError, ProviderDisconnectedError, ResourceNotFoundRpcError, ResourceUnavailableRpcError, TimeoutError, UnknownRpcError, UnsupportedProviderMethodError, UserRejectedRequestError } from 'viem';

/**
 * @typedef {Object} BaseErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error|import('@ethereumjs/evm').EVMError|unknown} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 */
/**
 * @typedef {Object} BaseErrorType
 * @property {string} _tag - Internal tag for the error.
 * @property {string} name - The name of the error.
 * @property {string} message - Human-readable error message.
 * @property {string} details - Details of the error.
 * @property {string|undefined} [docsPath] - Path to the documentation for this error.
 * @property {string} shortMessage - Short message describing the error.
 * @property {string} version - The version of the library.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {Function} walk - Function to walk through the error chain.
 */
/**
 * Base class for custom errors in TEVM.
 * This class is abstract and should be extended by other error classes.
 * @abstract
 * @extends {Error}
 * @implements {BaseErrorType}
 */
declare class BaseError extends Error implements BaseErrorType {
    /**
     * @param {string} shortMessage - A short, human-readable summary of the error.
     * @param {BaseErrorParameters} args={} - Additional parameters for the error.
     * @param {string} _tag - Internal tag for the error.
     * @param {number} [code] - Error code analogous to the code in JSON RPC error.
     */
    constructor(shortMessage: string, args: BaseErrorParameters, _tag: string, code?: number);
    /**
     * @type {string}
     */
    _tag: string;
    /**
     * @type {string}
     */
    details: string;
    /**
     * @type {string|undefined}
     */
    docsPath: string | undefined;
    /**
     * @type {string[]|undefined}
     */
    metaMessages: string[] | undefined;
    /**
     * @type {string}
     */
    shortMessage: string;
    /**
     * @type {string}
     */
    version: string;
    /**
     * @type {number}
     */
    code: number;
    cause: any;
    /**
     * Walks through the error chain.
     * @param {Function} [fn] - A function to execute on each error in the chain.
     * @returns {Error|unknown} The first error that matches the function, or the original error.
     */
    walk(fn?: Function): Error | unknown;
}
type BaseErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error | _ethereumjs_evm.EVMError | unknown;
    /**
     * - Details of the error.
     */
    details?: string;
};
type BaseErrorType = {
    /**
     * - Internal tag for the error.
     */
    _tag: string;
    /**
     * - The name of the error.
     */
    name: string;
    /**
     * - Human-readable error message.
     */
    message: string;
    /**
     * - Details of the error.
     */
    details: string;
    /**
     * - Path to the documentation for this error.
     */
    docsPath?: string | undefined;
    /**
     * - Short message describing the error.
     */
    shortMessage: string;
    /**
     * - The version of the library.
     */
    version: string;
    /**
     * - Error code, analogous to the code in JSON RPC error.
     */
    code: number;
    /**
     * - Function to walk through the error chain.
     */
    walk: Function;
};

/**
 * Parameters for constructing an InvalidParamsError.
 * @typedef {Object} InvalidParamsErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when invalid method parameters are provided.
 *
 * This error is typically encountered when a JSON-RPC request is made with parameters that are not valid or do not match the expected types.
 *
 * @example
 * try {
 *   // Some operation that can throw an InvalidParamsError
 * } catch (error) {
 *   if (error instanceof InvalidParamsError) {
 *     console.error(error.message);
 *     // Handle the invalid params error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InvalidParamsErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidParams'} _tag - Same as name, used internally.
 * @property {'InvalidParams'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidParamsError extends BaseError {
    /**
     * The error code for InvalidParamsError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs an InvalidParamsError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidParamsErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidParams'] - The tag for the error.
     */
    constructor(message: string, args?: InvalidParamsErrorParameters, tag?: string);
}
/**
 * Parameters for constructing an InvalidParamsError.
 */
type InvalidParamsErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidAbiError.
 * @typedef {Object} InvalidAbiErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the ABI is invalid.
 *
 * This error is typically encountered when a contract interaction or ABI-related operation receives an invalid or malformed ABI.
 *
 * @example
 * ```javascript
 * import { InvalidAbiError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.contract({
 *     abi: 'invalid_abi', // This should be a valid ABI array
 *     address: '0x...',
 *     functionName: 'someFunction',
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidAbiError) {
 *     console.error('Invalid ABI:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidAbiError extends InvalidParamsError {
    /**
     * Constructs an InvalidAbiError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidAbiErrorParameters} [args={}] - Additional parameters for the InvalidAbiError.
     */
    constructor(message: string, args?: InvalidAbiErrorParameters);
}
/**
 * Parameters for constructing an InvalidAbiError.
 */
type InvalidAbiErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidArgsError.
 * @typedef {Object} InvalidArgsErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the arguments provided to a function or method are invalid.
 *
 * This error is typically encountered when a function receives arguments that don't match the expected types or format.
 *
 * @example
 * ```javascript
 * import { InvalidArgsError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.contract({
 *     address: '0x...',
 *     functionName: 'transfer',
 *     args: ['not_an_address', 'not_a_number'], // Invalid args
 *     abi: [...],
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidArgsError) {
 *     console.error('Invalid arguments:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidArgsError extends InvalidParamsError {
    /**
     * Constructs an InvalidArgsError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidArgsErrorParameters} [args={}] - Additional parameters for the InvalidArgsError.
     */
    constructor(message: string, args?: InvalidArgsErrorParameters);
}
/**
 * Parameters for constructing an InvalidArgsError.
 */
type InvalidArgsErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidBalanceError.
 * @typedef {Object} InvalidBalanceErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when an account balance is invalid.
 *
 * This error is typically encountered when setting or manipulating account balances with invalid values.
 *
 * @example
 * ```javascript
 * import { InvalidBalanceError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.setAccount({
 *     address: '0x...',
 *     balance: -1000n, // Invalid negative balance
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidBalanceError) {
 *     console.error('Invalid balance:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidBalanceError extends InvalidParamsError {
    /**
     * Constructs an InvalidBalanceError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidBalanceErrorParameters} [args={}] - Additional parameters for the InvalidBalanceError.
     */
    constructor(message: string, args?: InvalidBalanceErrorParameters);
}
/**
 * Parameters for constructing an InvalidBalanceError.
 */
type InvalidBalanceErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidBytecodeError.
 * @typedef {Object} InvalidBytecodeErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the bytecode parameter is invalid.
 *
 * This error is typically encountered when a transaction or operation references a bytecode parameter that is invalid or does not conform to the expected structure.
 *
 * @example
 * try {
 *   // Some operation that can throw an InvalidBytecodeError
 * } catch (error) {
 *   if (error instanceof InvalidBytecodeError) {
 *     console.error(error.message);
 *     // Handle the invalid bytecode error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InvalidBytecodeErrorParameters} [args={}] - Additional parameters for the InvalidBytecodeError.
 * @property {'InvalidBytecodeError'} _tag - Same as name, used internally.
 * @property {'InvalidBytecodeError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidBytecodeError extends InvalidParamsError {
}
/**
 * Parameters for constructing an InvalidBytecodeError.
 */
type InvalidBytecodeErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidDataError.
 * @typedef {Object} InvalidDataErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the data provided is invalid.
 *
 * This error is typically encountered when an operation receives invalid or malformed data.
 *
 * @example
 * ```javascript
 * import { InvalidDataError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.sendTransaction({
 *     from: '0x1234567890123456789012345678901234567890',
 *     to: '0x0987654321098765432109876543210987654321',
 *     data: 'not_valid_hex_data', // Should be a valid hex string
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidDataError) {
 *     console.error('Invalid data:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidDataError extends InvalidParamsError {
    /**
     * Constructs an InvalidDataError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidDataErrorParameters} [args={}] - Additional parameters for the InvalidDataError.
     */
    constructor(message: string, args?: InvalidDataErrorParameters);
}
/**
 * Parameters for constructing an InvalidDataError.
 */
type InvalidDataErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidStorageRootError.
 * @typedef {Object} InvalidStorageRootErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the storage root parameter is invalid.
 *
 * This error is typically encountered when a transaction or operation references a storage root parameter that is invalid or does not conform to the expected structure.
 *
 * @example
 * ```javascript
 * import { InvalidStorageRootError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.setAccount({
 *     address: '0x...',
 *     storageRoot: 'invalid', // This should be a valid storage root
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidStorageRootError) {
 *     console.error('Invalid storage root:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidStorageRootError extends InvalidParamsError {
    /**
     * Constructs an InvalidStorageRootError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidStorageRootErrorParameters} [args={}] - Additional parameters for the InvalidStorageRootError.
     */
    constructor(message: string, args?: InvalidStorageRootErrorParameters);
}
/**
 * Parameters for constructing an InvalidStorageRootError.
 */
type InvalidStorageRootErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidFunctionNameError.
 * @typedef {Object} InvalidFunctionNameErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the function name is invalid.
 *
 * This error is typically encountered when trying to call a contract function with an invalid or non-existent function name.
 *
 * @example
 * ```javascript
 * import { InvalidFunctionNameError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.contract({
 *     address: '0x1234567890123456789012345678901234567890',
 *     abi: [...],
 *     functionName: 'nonExistentFunction',
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidFunctionNameError) {
 *     console.error('Invalid function name:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidFunctionNameError extends InvalidParamsError {
    /**
     * Constructs an InvalidFunctionNameError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidFunctionNameErrorParameters} [args={}] - Additional parameters for the InvalidFunctionNameError.
     */
    constructor(message: string, args?: InvalidFunctionNameErrorParameters);
}
/**
 * Parameters for constructing an InvalidFunctionNameError.
 */
type InvalidFunctionNameErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidDeployedBytecodeError.
 * @typedef {Object} InvalidDeployedBytecodeErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the deployedBytecode parameter is invalid.
 *
 * This error is typically encountered when a transaction or operation references a deployedBytecode parameter that is invalid or does not conform to the expected structure.
 *
 * @example
 * ```javascript
 * import { InvalidDeployedBytecodeError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.setAccount({
 *     address: '0x...',
 *     deployedBytecode: 'invalid', // This should be valid bytecode
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidDeployedBytecodeError) {
 *     console.error('Invalid deployed bytecode:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidDeployedBytecodeError extends InvalidParamsError {
    /**
     * Constructs an InvalidDeployedBytecodeError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidDeployedBytecodeErrorParameters} [args={}] - Additional parameters for the InvalidDeployedBytecodeError.
     */
    constructor(message: string, args?: InvalidDeployedBytecodeErrorParameters);
}
/**
 * Parameters for constructing an InvalidDeployedBytecodeError.
 */
type InvalidDeployedBytecodeErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidGasLimitError.
 * @typedef {Object} InvalidGasLimitErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the gas limit is invalid.
 *
 * This error is typically encountered when a transaction or operation specifies an invalid gas limit.
 *
 * @example
 * ```javascript
 * import { InvalidGasLimitError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.sendTransaction({
 *     from: '0x1234567890123456789012345678901234567890',
 *     to: '0x0987654321098765432109876543210987654321',
 *     gasLimit: -1n, // Invalid negative gas limit
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidGasLimitError) {
 *     console.error('Invalid gas limit:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidGasLimitError extends InvalidParamsError {
    /**
     * Constructs an InvalidGasLimitError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidGasLimitErrorParameters} [args={}] - Additional parameters for the InvalidGasLimitError.
     */
    constructor(message: string, args?: InvalidGasLimitErrorParameters);
}
/**
 * Parameters for constructing an InvalidGasLimitError.
 */
type InvalidGasLimitErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidBlobVersionedHashesError.
 * @typedef {Object} InvalidBlobVersionedHashesErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the blobVersionedHashes parameter is invalid.
 *
 * This error is typically encountered when a transaction or operation references a blobVersionedHashes parameter that is malformed or does not conform to the expected structure.
 *
 * @example
 * ```javascript
 * import { InvalidBlobVersionedHashesError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.sendTransaction({
 *     // ... other transaction parameters
 *     blobVersionedHashes: ['invalid_hash'], // This should be a valid versioned hash
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidBlobVersionedHashesError) {
 *     console.error('Invalid blob versioned hashes:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidBlobVersionedHashesError extends InvalidParamsError {
    /**
     * Constructs an InvalidBlobVersionedHashesError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidBlobVersionedHashesErrorParameters} [args={}] - Additional parameters for the InvalidBlobVersionedHashesError.
     */
    constructor(message: string, args?: InvalidBlobVersionedHashesErrorParameters);
}
/**
 * Parameters for constructing an InvalidBlobVersionedHashesError.
 */
type InvalidBlobVersionedHashesErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidOriginError.
 * @typedef {Object} InvalidOriginErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the origin parameter is invalid.
 *
 * This error is typically encountered when a transaction or operation references an origin parameter that is invalid or does not conform to the expected structure.
 *
 * @example
 * try {
 *   // Some operation that can throw an InvalidOriginError
 * } catch (error) {
 *   if (error instanceof InvalidOriginError) {
 *     console.error(error.message);
 *     // Handle the invalid origin error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InvalidOriginErrorParameters} [args={}] - Additional parameters for the InvalidOriginError.
 * @property {'InvalidOriginError'} _tag - Same as name, used internally.
 * @property {'InvalidOriginError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidOriginError extends InvalidParamsError {
}
/**
 * Parameters for constructing an InvalidOriginError.
 */
type InvalidOriginErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidToError.
 * @typedef {Object} InvalidToErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the 'to' address in a transaction or operation is invalid.
 *
 * This error is typically encountered when a transaction or contract interaction specifies an invalid recipient address.
 *
 * @example
 * ```javascript
 * import { InvalidToError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.sendTransaction({
 *     from: '0x1234567890123456789012345678901234567890',
 *     to: 'invalid_address', // Invalid 'to' address
 *     value: 1000n,
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidToError) {
 *     console.error('Invalid to address:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidToError extends InvalidParamsError {
    /**
     * Constructs an InvalidToError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidToErrorParameters} [args={}] - Additional parameters for the InvalidToError.
     */
    constructor(message: string, args?: InvalidToErrorParameters);
}
/**
 * Parameters for constructing an InvalidToError.
 */
type InvalidToErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidCallerError.
 * @typedef {Object} InvalidCallerErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the caller parameter is invalid.
 *
 * This error is typically encountered when a transaction or operation references a caller parameter that is invalid or does not conform to the expected structure.
 *
 * @example
 * try {
 *   // Some operation that can throw an InvalidCallerError
 * } catch (error) {
 *   if (error instanceof InvalidCallerError) {
 *     console.error(error.message);
 *     // Handle the invalid caller error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InvalidCallerErrorParameters} [args={}] - Additional parameters for the InvalidCallerError.
 * @property {'InvalidCallerError'} _tag - Same as name, used internally.
 * @property {'InvalidCallerError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidCallerError extends InvalidParamsError {
}
/**
 * Parameters for constructing an InvalidCallerError.
 */
type InvalidCallerErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidDepthError.
 * @typedef {Object} InvalidDepthErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the depth parameter is invalid.
 *
 * This error is typically encountered when a transaction or operation references a depth parameter that is invalid or does not conform to the expected structure.
 *
 * @example
 * try {
 *   // Some operation that can throw an InvalidDepthError
 * } catch (error) {
 *   if (error instanceof InvalidDepthError) {
 *     console.error(error.message);
 *     // Handle the invalid depth error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InvalidDepthErrorParameters} [args={}] - Additional parameters for the InvalidDepthError.
 * @property {'InvalidDepthError'} _tag - Same as name, used internally.
 * @property {'InvalidDepthError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidDepthError extends InvalidParamsError {
}
/**
 * Parameters for constructing an InvalidDepthError.
 */
type InvalidDepthErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidGasRefundError.
 * @typedef {Object} InvalidGasRefundErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the gas refund is invalid.
 *
 * This error is typically encountered when a transaction or operation specifies an invalid gas refund value.
 *
 * @example
 * ```javascript
 * import { InvalidGasRefundError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.setAccount({
 *     address: '0x1234567890123456789012345678901234567890',
 *     gasRefund: -1n, // Invalid negative gas refund
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidGasRefundError) {
 *     console.error('Invalid gas refund:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidGasRefundError extends InvalidParamsError {
    /**
     * Constructs an InvalidGasRefundError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidGasRefundErrorParameters} [args={}] - Additional parameters for the InvalidGasRefundError.
     */
    constructor(message: string, args?: InvalidGasRefundErrorParameters);
}
/**
 * Parameters for constructing an InvalidGasRefundError.
 */
type InvalidGasRefundErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidNonceError.
 * @typedef {Object} InvalidNonceErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the nonce parameter is invalid.
 *
 * This error is typically encountered when a transaction or operation references a nonce parameter that is invalid or does not conform to the expected structure.
 *
 * @example
 * try {
 *   // Some operation that can throw an InvalidNonceError
 * } catch (error) {
 *   if (error instanceof InvalidNonceError) {
 *     console.error(error.message);
 *     // Handle the invalid nonce error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InvalidNonceErrorParameters} [args={}] - Additional parameters for the InvalidNonceError.
 * @property {'InvalidNonceError'} _tag - Same as name, used internally.
 * @property {'InvalidNonceError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidNonceError extends InvalidParamsError {
}
/**
 * Parameters for constructing an InvalidNonceError.
 */
type InvalidNonceErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidSaltError.
 * @typedef {Object} InvalidSaltErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the salt parameter is invalid.
 *
 * This error is typically encountered when a transaction or operation references a salt parameter that is invalid or does not conform to the expected structure.
 *
 * @example
 * try {
 *   // Some operation that can throw an InvalidSaltError
 * } catch (error) {
 *   if (error instanceof InvalidSaltError) {
 *     console.error(error.message);
 *     // Handle the invalid salt error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InvalidSaltErrorParameters} [args={}] - Additional parameters for the InvalidSaltError.
 * @property {'InvalidSaltError'} _tag - Same as name, used internally.
 * @property {'InvalidSaltError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidSaltError extends InvalidParamsError {
}
/**
 * Parameters for constructing an InvalidSaltError.
 */
type InvalidSaltErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidBlockError.
 * @typedef {Object} InvalidBlockErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the block parameter is invalid.
 *
 * This error is typically encountered when a transaction or operation references a block, blockTag, or blockNumber parameter that is invalid or does not conform to the expected structure.
 *
 * Currently most named block tags are not supported on all endpoints except for `latest` and 'earliest'. This will be expanded in near future.
 *
 * @example
 * try {
 *   // Some operation that can throw an InvalidBlockError
 * } catch (error) {
 *   if (error instanceof InvalidBlockError) {
 *     console.error(error.message);
 *     // Handle the invalid block error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InvalidBlockErrorParameters} [args={}] - Additional parameters for the InvalidBlockError.
 * @property {'InvalidBlockError'} _tag - Same as name, used internally.
 * @property {'InvalidBlockError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidBlockError extends InvalidParamsError {
}
/**
 * Parameters for constructing an InvalidBlockError.
 */
type InvalidBlockErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidValueError.
 * @typedef {Object} InvalidValueErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the 'value' parameter is invalid.
 *
 * This error is typically encountered when a transaction or operation references a 'value' parameter that is invalid or does not conform to the expected structure.
 *
 * @example
 * try {
 *   // Some operation that can throw an InvalidValueError
 * } catch (error) {
 *   if (error instanceof InvalidValueError) {
 *     console.error(error.message);
 *     // Handle the invalid 'value' error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InvalidValueErrorParameters} [args={}] - Additional parameters for the InvalidValueError.
 * @property {'InvalidValueError'} _tag - Same as name, used internally.
 * @property {'InvalidValueError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidValueError extends InvalidParamsError {
}
/**
 * Parameters for constructing an InvalidValueError.
 */
type InvalidValueErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidSkipBalanceError.
 * @typedef {Object} InvalidSkipBalanceErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the skipBalance parameter is invalid.
 *
 * This error is typically encountered when a transaction or operation uses an invalid skipBalance value.
 *
 * @example
 * ```javascript
 * import { InvalidSkipBalanceError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.setAccount({
 *     address: '0x...',
 *     skipBalance: 'invalid', // This should be a boolean
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidSkipBalanceError) {
 *     console.error('Invalid skipBalance:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidSkipBalanceError extends InvalidParamsError {
    /**
     * Constructs an InvalidSkipBalanceError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidSkipBalanceErrorParameters} [args={}] - Additional parameters for the InvalidSkipBalanceError.
     */
    constructor(message: string, args?: InvalidSkipBalanceErrorParameters);
}
/**
 * Parameters for constructing an InvalidSkipBalanceError.
 */
type InvalidSkipBalanceErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidSelfdestructError.
 * @typedef {Object} InvalidSelfdestructErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the selfdestruct parameter is invalid.
 *
 * This error is typically encountered when setting an account's selfdestruct status with an invalid value.
 *
 * @example
 * ```javascript
 * import { InvalidSelfdestructError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.setAccount({
 *     address: '0x1234567890123456789012345678901234567890',
 *     selfdestruct: 'not_a_boolean', // Should be a boolean
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidSelfdestructError) {
 *     console.error('Invalid selfdestruct value:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidSelfdestructError extends InvalidParamsError {
    /**
     * Constructs an InvalidSelfdestructError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidSelfdestructErrorParameters} [args={}] - Additional parameters for the InvalidSelfdestructError.
     */
    constructor(message: string, args?: InvalidSelfdestructErrorParameters);
}
/**
 * Parameters for constructing an InvalidSelfdestructError.
 */
type InvalidSelfdestructErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidUrlError.
 * @typedef {Object} InvalidUrlErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when a URL is invalid.
 *
 * This error is typically encountered when an operation requires a valid URL, but receives an invalid one.
 *
 * @example
 * ```javascript
 * import { InvalidUrlError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * try {
 *   const client = createMemoryClient({
 *     fork: {
 *       url: 'not_a_valid_url'
 *     }
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidUrlError) {
 *     console.error('Invalid URL:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidUrlError extends InvalidParamsError {
    /**
     * Constructs an InvalidUrlError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidUrlErrorParameters} [args={}] - Additional parameters for the InvalidUrlError.
     */
    constructor(message: string, args?: InvalidUrlErrorParameters);
}
/**
 * Parameters for constructing an InvalidUrlError.
 */
type InvalidUrlErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidMaxFeePerGasError.
 * @typedef {Object} InvalidMaxFeePerGasErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the max fee per gas is invalid.
 *
 * This error is typically encountered when a transaction specifies an invalid max fee per gas value.
 *
 * @example
 * ```javascript
 * import { InvalidMaxFeePerGasError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.sendTransaction({
 *     from: '0x1234567890123456789012345678901234567890',
 *     to: '0x0987654321098765432109876543210987654321',
 *     maxFeePerGas: -1n, // Invalid negative max fee per gas
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidMaxFeePerGasError) {
 *     console.error('Invalid max fee per gas:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidMaxFeePerGasError extends InvalidParamsError {
    /**
     * Constructs an InvalidMaxFeePerGasError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidMaxFeePerGasErrorParameters} [args={}] - Additional parameters for the InvalidMaxFeePerGasError.
     */
    constructor(message: string, args?: InvalidMaxFeePerGasErrorParameters);
}
/**
 * Parameters for constructing an InvalidMaxFeePerGasError.
 */
type InvalidMaxFeePerGasErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidMaxPriorityFeePerGasError.
 * @typedef {Object} InvalidMaxPriorityFeePerGasErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the max priority fee per gas is invalid.
 *
 * This error is typically encountered when a transaction specifies an invalid max priority fee per gas value.
 *
 * @example
 * ```javascript
 * import { InvalidMaxPriorityFeePerGasError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.sendTransaction({
 *     from: '0x1234567890123456789012345678901234567890',
 *     to: '0x0987654321098765432109876543210987654321',
 *     maxPriorityFeePerGas: -1n, // Invalid negative max priority fee per gas
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidMaxPriorityFeePerGasError) {
 *     console.error('Invalid max priority fee per gas:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidMaxPriorityFeePerGasError extends InvalidParamsError {
    /**
     * Constructs an InvalidMaxPriorityFeePerGasError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidMaxPriorityFeePerGasErrorParameters} [args={}] - Additional parameters for the InvalidMaxPriorityFeePerGasError.
     */
    constructor(message: string, args?: InvalidMaxPriorityFeePerGasErrorParameters);
}
/**
 * Parameters for constructing an InvalidMaxPriorityFeePerGasError.
 */
type InvalidMaxPriorityFeePerGasErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidAddToMempoolError.
 * @typedef {Object} InvalidAddToMempoolErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the addToMempool parameter is invalid.
 *
 * This error is typically encountered when a transaction specifies an invalid addToMempool value.
 *
 * @example
 * ```javascript
 * import { InvalidAddToMempoolError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.call({
 *     to: '0x0987654321098765432109876543210987654321',
 *     data: '0x',
 *     addToMempool: 'invalid', // Should be boolean
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidAddToMempoolError) {
 *     console.error('Invalid addToMempool parameter:', error.message)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidAddToMempoolError extends InvalidParamsError {
    /**
     * Constructs an InvalidAddToMempoolError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidAddToMempoolErrorParameters} [args={}] - Additional parameters for the InvalidAddToMempoolError.
     */
    constructor(message: string, args?: InvalidAddToMempoolErrorParameters);
}
/**
 * Parameters for constructing an InvalidAddToMempoolError.
 */
type InvalidAddToMempoolErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidAddToBlockchainError.
 * @typedef {Object} InvalidAddToBlockchainErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the addToBlockchain parameter is invalid.
 *
 * This error is typically encountered when a transaction specifies an invalid addToBlockchain value.
 *
 * @example
 * ```javascript
 * import { InvalidAddToBlockchainError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   await client.call({
 *     to: '0x0987654321098765432109876543210987654321',
 *     data: '0x',
 *     addToBlockchain: 'invalid', // Should be boolean
 *   })
 * } catch (error) {
 *   if (error instanceof InvalidAddToBlockchainError) {
 *     console.error('Invalid addToBlockchain parameter:', error.message)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class InvalidAddToBlockchainError extends InvalidParamsError {
    /**
     * Constructs an InvalidAddToBlockchainError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidAddToBlockchainErrorParameters} [args={}] - Additional parameters for the InvalidAddToBlockchainError.
     */
    constructor(message: string, args?: InvalidAddToBlockchainErrorParameters);
}
/**
 * Parameters for constructing an InvalidAddToBlockchainError.
 */
type InvalidAddToBlockchainErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a DecodeFunctionDataError.
 * @typedef {Object} DecodeFunctionDataErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when decoding function data fails.
 * Not expected to be thrown unless ABI is incorrect.
 *
 * @example
 * ```javascript
 * import { DecodeFunctionDataError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   const result = await client.call({
 *     to: '0x1234567890123456789012345678901234567890',
 *     data: '0x...' // Invalid or mismatched function data
 *   })
 * } catch (error) {
 *   if (error instanceof DecodeFunctionDataError) {
 *     console.error('Decode function data error:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class DecodeFunctionDataError extends InvalidParamsError {
    /**
     * Constructs a DecodeFunctionDataError.
     *
     * @param {string} message - Human-readable error message.
     * @param {DecodeFunctionDataErrorParameters} [args={}] - Additional parameters for the DecodeFunctionDataError.
     */
    constructor(message: string, args?: DecodeFunctionDataErrorParameters);
}
/**
 * Parameters for constructing a DecodeFunctionDataError.
 */
type DecodeFunctionDataErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an EncodeFunctionReturnDataError.
 * @typedef {Object} EncodeFunctionReturnDataErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when encoding function return data fails.
 * Not expected to be thrown because the initial validation
 * should have caught any errors and thrown more specific errors.
 *
 * @example
 * ```javascript
 * import { EncodeFunctionReturnDataError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient()
 *
 * try {
 *   const result = await client.contract({
 *     address: '0x1234567890123456789012345678901234567890',
 *     abi: [...],
 *     functionName: 'someFunction',
 *   })
 *   // Assume some internal error occurs during encoding of the return data
 * } catch (error) {
 *   if (error instanceof EncodeFunctionReturnDataError) {
 *     console.error('Encode function return data error:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *   }
 * }
 * ```
 *
 * @extends {InvalidParamsError}
 */
declare class EncodeFunctionReturnDataError extends InvalidParamsError {
    /**
     * Constructs an EncodeFunctionReturnDataError.
     *
     * @param {string} message - Human-readable error message.
     * @param {EncodeFunctionReturnDataErrorParameters} [args={}] - Additional parameters for the EncodeFunctionReturnDataError.
     */
    constructor(message: string, args?: EncodeFunctionReturnDataErrorParameters);
}
/**
 * Parameters for constructing an EncodeFunctionReturnDataError.
 */
type EncodeFunctionReturnDataErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a ForkError.
 * @typedef {Object} ForkErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error|{code: number | string, message: string}} cause - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error thrown when attempting to fetch a resource from a Forked transport.
 * If the underlying JSON-RPC call has an error code, the error code will be proxied to the ForkError.
 *
 * @example
 * ```javascript
 * import { ForkError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 * import { http } from '@tevm/jsonrpc'
 *
 * const client = createMemoryClient({
 *   fork: {
 *     url: 'https://mainnet.example.com'
 *   }
 * })
 *
 * try {
 *   await client.getBalance('0x...')
 * } catch (error) {
 *   if (error instanceof ForkError) {
 *     console.error('Fork error:', error.message)
 *     console.log('Error code:', error.code)
 *     console.log('Documentation:', error.docsLink)
 *     // Handle the fork error, e.g., by retrying or using a different RPC endpoint
 *   }
 * }
 * ```
 *
 * @extends {BaseError}
 */
declare class ForkError extends BaseError {
    /**
     * Constructs a ForkError.
     *
     * @param {string} message - Human-readable error message.
     * @param {ForkErrorParameters} args - Additional parameters for the error.
     */
    constructor(message: string, args: ForkErrorParameters);
}
/**
 * Parameters for constructing a ForkError.
 */
type ForkErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause: BaseError | Error | {
        code: number | string;
        message: string;
    };
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a NoForkTransportSetError.
 * @typedef {Object} NoForkTransportSetErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('../ethereum/BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Error represents the tevm client attempted to fetch a resource from a Forked transport but no transport was set.
 *
 * @example
 * ```javascript
 * import { NoForkTransportSetError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 *
 * const client = createMemoryClient() // No fork configuration
 *
 * try {
 *   await client.getBalance('0x...') // This might throw if it needs to access forked state
 * } catch (error) {
 *   if (error instanceof NoForkTransportSetError) {
 *     console.error('No fork transport set:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *     // Handle the error, e.g., by setting up a fork configuration
 *   }
 * }
 * ```
 *
 * @extends {BaseError}
 */
declare class NoForkTransportSetError extends BaseError {
    /**
     * Constructs a NoForkTransportSetError.
     *
     * @param {string} message - Human-readable error message.
     * @param {NoForkTransportSetErrorParameters} [args] - Additional parameters for the error.
     */
    constructor(message: string, args?: NoForkTransportSetErrorParameters);
}
/**
 * Parameters for constructing a NoForkTransportSetError.
 */
type NoForkTransportSetErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an AccountLockedError.
 * @typedef {Object} AccountLockedErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when an account is locked.
 *
 * This error is typically encountered when an operation is attempted on an account
 * that has been locked for security reasons. This might happen if the account has
 * been temporarily disabled, if additional authentication is required, or if the
 * account's private key is not available to the node.
 *
 * The error code -32005 is a non-standard extension used by some Ethereum clients to
 * indicate this specific condition.
 *
 * @example
 * try {
 *   await client.sendTransaction({
 *     from: '0x1234567890123456789012345678901234567890',
 *     to: '0x0987654321098765432109876543210987654321',
 *     value: '0x1'
 *   })
 * } catch (error) {
 *   if (error instanceof AccountLockedError) {
 *     console.error('Account locked:', error.message);
 *     console.log('Unlock the account or use a different account for this transaction');
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {AccountLockedErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'AccountLocked'} _tag - Same as name, used internally.
 * @property {'AccountLocked'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code (-32005), a non-standard extension for this specific error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class AccountLockedError extends BaseError {
    /**
     * The error code for AccountLockedError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs an AccountLockedError.
     *
     * @param {string} message - Human-readable error message.
     * @param {AccountLockedErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='AccountLocked'] - The tag for the error.
     */
    constructor(message: string, args?: AccountLockedErrorParameters, tag?: string);
}
/**
 * Parameters for constructing an AccountLockedError.
 */
type AccountLockedErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a BlockGasLimitExceededError.
 * @typedef {Object} BlockGasLimitExceededErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the block gas limit has been exceeded.
 *
 * This error is typically encountered when a transaction or set of transactions in a block
 * consume more gas than the block's gas limit allows. Each block in Ethereum has a maximum
 * amount of gas that can be used by all transactions within it.
 *
 * The error code -32006 is a non-standard extension used by some Ethereum clients to
 * indicate this specific condition.
 *
 * @example
 * try {
 *   const result = await client.sendTransaction({
 *     // ... transaction details
 *   })
 * } catch (error) {
 *   if (error instanceof BlockGasLimitExceededError) {
 *     console.error('Block gas limit exceeded:', error.message);
 *     console.log('Consider splitting the transaction or waiting for a block with more available gas');
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {BlockGasLimitExceededErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'BlockGasLimitExceeded'} _tag - Same as name, used internally.
 * @property {'BlockGasLimitExceeded'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code (-32006), a non-standard extension for this specific error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class BlockGasLimitExceededError extends BaseError {
    /**
     * The error code for BlockGasLimitExceededError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs a BlockGasLimitExceededError.
     *
     * @param {string} message - Human-readable error message.
     * @param {BlockGasLimitExceededErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='BlockGasLimitExceededError'] - The tag for the error.
     */
    constructor(message: string, args?: BlockGasLimitExceededErrorParameters, tag?: string);
    /**
     * @type {object|undefined}
     */
    meta: object | undefined;
    /**
     * @type {'BlockGasLimitExceeded'}
     * @override
     */
    override _tag: "BlockGasLimitExceeded";
    /**
     * @type {'BlockGasLimitExceeded'}
     * @override
     */
    override name: "BlockGasLimitExceeded";
}
/**
 * Parameters for constructing a BlockGasLimitExceededError.
 */
type BlockGasLimitExceededErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a ChainIdMismatchError.
 * @typedef {Object} ChainIdMismatchErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the chain ID does not match the expected value.
 *
 * This error is typically encountered when a transaction or operation specifies a chain ID that does not match the chain ID of the Ethereum node.
 *
 * @example
 * try {
 *   // Some operation that can throw a ChainIdMismatchError
 * } catch (error) {
 *   if (error instanceof ChainIdMismatchError) {
 *     console.error(error.message);
 *     // Handle the chain ID mismatch error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {ChainIdMismatchErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'ChainIdMismatch'} _tag - Same as name, used internally.
 * @property {'ChainIdMismatch'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class ChainIdMismatchError extends BaseError {
    /**
     * The error code for ChainIdMismatchError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs a ChainIdMismatchError.
     *
     * @param {string} message - Human-readable error message.
     * @param {ChainIdMismatchErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='ChainIdMismatch'] - The tag for the error.
     */
    constructor(message: string, args?: ChainIdMismatchErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a ChainIdMismatchError.
 */
type ChainIdMismatchErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a ContractExecutionFailedError.
 * @typedef {Object} ContractExecutionFailedErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the execution of a smart contract fails.
 *
 * This error is typically encountered when a smart contract's execution reverts or
 * encounters an exception during its operation. It can be due to various reasons such as
 * failing assertions, out-of-gas errors, or other contract-specific logic failures.
 *
 * The error code -32004 is a non-standard extension used by some Ethereum clients to
 * indicate a contract execution failure.
 *
 * @example
 * try {
 *   const result = await client.call({
 *     to: '0x742d35Cc6634C0532925a3b844Bc454e4438f44e',
 *     data: '0x...' // encoded function call
 *   })
 * } catch (error) {
 *   if (error instanceof ContractExecutionFailedError) {
 *     console.error('Contract execution failed:', error.message);
 *     console.log('Check the contract logic or input parameters');
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {ContractExecutionFailedErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'ContractExecutionFailed'} _tag - Same as name, used internally.
 * @property {'ContractExecutionFailed'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code (-32004), a non-standard extension for this specific error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class ContractExecutionFailedError extends BaseError {
    /**
     * The error code for ContractExecutionFailedError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs a ContractExecutionFailedError.
     *
     * @param {string} message - Human-readable error message.
     * @param {ContractExecutionFailedErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='ContractExecutionFailed'] - The tag for the error.
     */
    constructor(message: string, args?: ContractExecutionFailedErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a ContractExecutionFailedError.
 */
type ContractExecutionFailedErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an ExecutionError.
 * @typedef {Object} ExecutionErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when an execution error happens on the Ethereum node.
 *
 * This error is typically encountered when there is a general execution error that does not fit more specific categories.
 *
 * @example
 * try {
 *   // Some operation that can throw an ExecutionError
 * } catch (error) {
 *   if (error instanceof ExecutionError) {
 *     console.error(error.message);
 *     // Handle the execution error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {ExecutionErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {string} _tag - More discriminated version of name. Can be used to discriminate between errors with the same name.
 * @property {'ExecutionError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class ExecutionError extends BaseError {
    /**
     * The error code for ExecutionError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs an ExecutionError.
     *
     * @param {string} message - Human-readable error message.
     * @param {ExecutionErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag] - Internal name/tag for the error.
     */
    constructor(message: string, args?: ExecutionErrorParameters, tag?: string);
}
/**
 * Parameters for constructing an ExecutionError.
 */
type ExecutionErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a GasLimitExceededError.
 * @typedef {Object} GasLimitExceededErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the gas limit is exceeded.
 *
 * This error is typically encountered when a transaction or set of transactions exceed the specified gas limit.
 *
 * @example
 * try {
 *   // Some operation that can throw a GasLimitExceededError
 * } catch (error) {
 *   if (error instanceof GasLimitExceededError) {
 *     console.error(error.message);
 *     // Handle the gas limit exceeded error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {GasLimitExceededErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {string} _tag - Same as name, used internally.
 * @property {string} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class GasLimitExceededError extends BaseError {
    /**
     * Constructs a GasLimitExceededError.
     *
     * @param {string} message - Human-readable error message.
     * @param {GasLimitExceededErrorParameters} [args={}] - Additional parameters for the BaseError.
     */
    constructor(message: string, args?: GasLimitExceededErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a GasLimitExceededError.
 */
type GasLimitExceededErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InsufficientFundsError.
 * @typedef {Object} InsufficientFundsErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when there are insufficient funds for a transaction.
 *
 * This error is typically encountered when a transaction is attempted with a balance that is too low to cover the transaction cost.
 *
 * @example
 * try {
 *   // Some operation that can throw an InsufficientFundsError
 * } catch (error) {
 *   if (error instanceof InsufficientFundsError) {
 *     console.error(error.message);
 *     // Handle the insufficient funds error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InsufficientFundsErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InsufficientFunds'} _tag - Same as name, used internally.
 * @property {'InsufficientFunds'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InsufficientFundsError extends BaseError {
    /**
     * Constructs an InsufficientFundsError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InsufficientFundsErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InsufficientFunds'] - The tag for the error.
     */
    constructor(message: string, args?: InsufficientFundsErrorParameters, tag?: string);
}
/**
 * Parameters for constructing an InsufficientFundsError.
 */
type InsufficientFundsErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InsufficientPermissionsError.
 * @typedef {Object} InsufficientPermissionsErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when there are insufficient permissions for a requested operation.
 *
 * This error is typically encountered when an action is attempted without the necessary permissions.
 *
 * @example
 * try {
 *   // Some operation that can throw an InsufficientPermissionsError
 * } catch (error) {
 *   if (error instanceof InsufficientPermissionsError) {
 *     console.error(error.message);
 *     // Handle the insufficient permissions error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InsufficientPermissionsErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InsufficientPermissions'} _tag - Same as name, used internally.
 * @property {'InsufficientPermissions'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InsufficientPermissionsError extends BaseError {
    /**
     * The error code for InsufficientPermissionsError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs an InsufficientPermissionsError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InsufficientPermissionsErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InsufficientPermissions'] - The tag for the error.
     */
    constructor(message: string, args?: InsufficientPermissionsErrorParameters, tag?: string);
}
/**
 * Parameters for constructing an InsufficientPermissionsError.
 */
type InsufficientPermissionsErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InternalError.
 * @typedef {Object} InternalErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error|unknown} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an internal JSON-RPC error.
 *
 * This error is typically encountered when there is an unexpected internal error on the server.
 * It's a catch-all for errors that don't fall into more specific categories and usually indicates
 * a problem with the Ethereum node or the JSON-RPC server itself, rather than with the request.
 *
 * The error code -32603 is a standard JSON-RPC error code for internal errors.
 *
 * @example
 * try {
 *   await client.call({
 *     to: '0x742d35Cc6634C0532925a3b844Bc454e4438f44e',
 *     data: '0x...' // some method call
 *   })
 * } catch (error) {
 *   if (error instanceof InternalError) {
 *     console.error('Internal error:', error.message);
 *     console.log('This is likely a problem with the Ethereum node. Try again later or contact the node operator.');
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InternalErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InternalError'} _tag - Same as name, used internally.
 * @property {'InternalError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code (-32603), standard JSON-RPC error code for internal errors.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InternalError extends BaseError {
    /**
     * The error code for InternalError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs an InternalError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InternalErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InternalError'] - The tag for the error.
     */
    constructor(message: string, args?: InternalErrorParameters, tag?: string);
    meta: object | undefined;
}
/**
 * Parameters for constructing an InternalError.
 */
type InternalErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error | unknown;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidAddressError.
 * @typedef {Object} InvalidAddressErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the specified address is invalid.
 *
 * This error is typically encountered when an address provided in a transaction or contract call is not a valid Ethereum address.
 *
 * @example
 * try {
 *   // Some operation that can throw an InvalidAddressError
 * } catch (error) {
 *   if (error instanceof InvalidAddressError) {
 *     console.error(error.message);
 *     // Handle the invalid address error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InvalidAddressErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidAddress'} _tag - Same as name, used internally.
 * @property {'InvalidAddress'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidAddressError extends BaseError {
    /**
     * Constructs an InvalidAddressError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidAddressErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidAddress'] - The tag for the error.
     */
    constructor(message: string, args?: InvalidAddressErrorParameters, tag?: string);
}
/**
 * Parameters for constructing an InvalidAddressError.
 */
type InvalidAddressErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidGasPriceError.
 * @typedef {Object} InvalidGasPriceErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the specified gas price is invalid.
 *
 * This error is typically encountered when a transaction is submitted with a gas price that is not acceptable by the Ethereum network.
 *
 * @example
 * try {
 *   // Some operation that can throw an InvalidGasPriceError
 * } catch (error) {
 *   if (error instanceof InvalidGasPriceError) {
 *     console.error(error.message);
 *     // Handle the invalid gas price error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InvalidGasPriceErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidGasPrice'} _tag - Same as name, used internally.
 * @property {'InvalidGasPrice'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidGasPriceError extends BaseError {
    /**
     * Constructs an InvalidGasPriceError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidGasPriceErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidGasPrice'] - The tag for the error.
     */
    constructor(message: string, args?: InvalidGasPriceErrorParameters, tag?: string);
}
/**
 * Parameters for constructing an InvalidGasPriceError.
 */
type InvalidGasPriceErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidRequestError.
 * @typedef {Object} InvalidRequestErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the JSON sent is not a valid Request object.
 *
 * This error is typically encountered when a JSON-RPC request is malformed or does not conform to the required structure.
 *
 * @example
 * try {
 *   // Some operation that can throw an InvalidRequestError
 * } catch (error) {
 *   if (error instanceof InvalidRequestError) {
 *     console.error(error.message);
 *     // Handle the invalid request error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InvalidRequestErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidRequest'} _tag - Same as name, used internally.
 * @property {'InvalidRequest'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidRequestError extends BaseError {
    /**
     * Constructs an InvalidRequestError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidRequestErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidRequest'] - The tag for the error.
     */
    constructor(message: string, args?: InvalidRequestErrorParameters, tag?: string);
}
/**
 * Parameters for constructing an InvalidRequestError.
 */
type InvalidRequestErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidSignatureError.
 * @typedef {Object} InvalidSignatureErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when an invalid signature is provided.
 *
 * This error is typically encountered when a transaction or message is signed with a signature that is not valid.
 *
 * @example
 * try {
 *   // Some operation that can throw an InvalidSignatureError
 * } catch (error) {
 *   if (error instanceof InvalidSignatureError) {
 *     console.error(error.message);
 *     // Handle the invalid signature error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InvalidSignatureErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidSignature'} _tag - Same as name, used internally.
 * @property {'InvalidSignature'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidSignatureError extends BaseError {
    /**
     * Constructs an InvalidSignatureError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidSignatureErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidSignature'] - The tag for the error.
     */
    constructor(message: string, args?: InvalidSignatureErrorParameters, tag?: string);
}
/**
 * Parameters for constructing an InvalidSignatureError.
 */
type InvalidSignatureErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an InvalidTransactionError.
 * @typedef {Object} InvalidTransactionErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when a transaction is invalid.
 *
 * This error is typically encountered when a transaction does not conform to the required format or rules of the Ethereum network.
 *
 * @example
 * try {
 *   // Some operation that can throw an InvalidTransactionError
 * } catch (error) {
 *   if (error instanceof InvalidTransactionError) {
 *     console.error(error.message);
 *     // Handle the invalid transaction error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {InvalidTransactionErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidTransaction'} _tag - Same as name, used internally.
 * @property {'InvalidTransaction'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidTransactionError extends BaseError {
    /**
     * Constructs an InvalidTransactionError.
     *
     * @param {string} message - Human-readable error message.
     * @param {InvalidTransactionErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidTransaction'] - The tag for the error.
     */
    constructor(message: string, args?: InvalidTransactionErrorParameters, tag?: string);
}
/**
 * Parameters for constructing an InvalidTransactionError.
 */
type InvalidTransactionErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a LimitExceededError.
 * @typedef {Object} LimitExceededErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when a request limit is exceeded.
 *
 * This error is typically encountered when a user or application exceeds the allowed number of requests within a certain timeframe.
 *
 * @example
 * try {
 *   // Some operation that can throw a LimitExceededError
 * } catch (error) {
 *   if (error instanceof LimitExceededError) {
 *     console.error(error.message);
 *     // Handle the limit exceeded error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {LimitExceededErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'LimitExceeded'} _tag - Same as name, used internally.
 * @property {'LimitExceeded'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class LimitExceededError extends BaseError {
    /**
     * The error code for LimitExceededError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs a LimitExceededError.
     *
     * @param {string} message - Human-readable error message.
     * @param {LimitExceededErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='LimitExceededError'] - The tag for the error.}
     */
    constructor(message: string, args?: LimitExceededErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a LimitExceededError.
 */
type LimitExceededErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a MethodNotFoundError.
 * @typedef {Object} MethodNotFoundErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the specified method does not exist or is not available.
 *
 * This error is typically encountered when a JSON-RPC request is made with a method name that the server does not recognize or support.
 *
 * @example
 * try {
 *   // Some operation that can throw a MethodNotFoundError
 * } catch (error) {
 *   if (error instanceof MethodNotFoundError) {
 *     console.error(error.message);
 *     // Handle the method not found error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {MethodNotFoundErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'MethodNotFound'} _tag - Same as name, used internally.
 * @property {'MethodNotFound'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class MethodNotFoundError extends BaseError {
    static code: number;
    /**
     * Constructs a MethodNotFoundError.
     *
     * @param {string} message - Human-readable error message.
     * @param {MethodNotFoundErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='MethodNotFound'] - The tag for the error.
     */
    constructor(message: string, args?: MethodNotFoundErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a MethodNotFoundError.
 */
type MethodNotFoundErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a MethodNotSupportedError.
 * @typedef {Object} MethodNotSupportedErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the requested method is not supported by the Ethereum node.
 *
 * This error is typically encountered when a JSON-RPC request is made with a method that the server does not support.
 *
 * @example
 * try {
 *   // Some operation that can throw a MethodNotSupportedError
 * } catch (error) {
 *   if (error instanceof MethodNotSupportedError) {
 *     console.error(error.message);
 *     // Handle the method not supported error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {MethodNotSupportedErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'MethodNotSupported'} _tag - Same as name, used internally.
 * @property {'MethodNotSupported'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class MethodNotSupportedError extends BaseError {
    /**
     * Constructs a MethodNotSupportedError.
     *
     * @param {string} message - Human-readable error message.
     * @param {MethodNotSupportedErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='MethodNotSupported'] - The tag for the error.
     */
    constructor(message: string, args?: MethodNotSupportedErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a MethodNotSupportedError.
 */
type MethodNotSupportedErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a NonceAlreadyUsedError.
 * @typedef {Object} NonceAlreadyUsedErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the specified nonce has already been used.
 *
 * This error is typically encountered when a transaction is attempted with a nonce that has already been used in a previous transaction.
 *
 * @example
 * try {
 *   // Some operation that can throw a NonceAlreadyUsedError
 * } catch (error) {
 *   if (error instanceof NonceAlreadyUsedError) {
 *     console.error(error.message);
 *     // Handle the nonce already used error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {NonceAlreadyUsedErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'NonceAlreadyUsed'} _tag - Same as name, used internally.
 * @property {'NonceAlreadyUsed'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class NonceAlreadyUsedError extends BaseError {
    /**
     * Constructs a NonceAlreadyUsedError.
     *
     * @param {string} message - Human-readable error message.
     * @param {NonceAlreadyUsedErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='NonceAlreadyUsed'] - The tag for the error.
     */
    constructor(message: string, args?: NonceAlreadyUsedErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a NonceAlreadyUsedError.
 */
type NonceAlreadyUsedErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a NonceTooHighError.
 * @typedef {Object} NonceTooHighErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the nonce value is too high for a transaction.
 *
 * This error is typically encountered when a transaction is submitted with a nonce that is higher
 * than the expected next nonce for the sender's account. In Ethereum, nonces must be used in strict
 * sequential order to ensure transactions are processed correctly.
 *
 * The error code -32000 is a standard Ethereum JSON-RPC error code indicating a generic server error,
 * which is often used for various transaction-related errors including nonce issues.
 *
 * @example
 * try {
 *   await client.sendTransaction({
 *     from: '0x1234567890123456789012345678901234567890',
 *     to: '0x0987654321098765432109876543210987654321',
 *     value: '0x1',
 *     nonce: 100 // Assuming this nonce is too high
 *   })
 * } catch (error) {
 *   if (error instanceof NonceTooHighError) {
 *     console.error('Nonce too high:', error.message);
 *     console.log('Try decreasing the nonce or use `await client.getTransactionCount(address)` to get the correct nonce');
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {NonceTooHighErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'NonceTooHigh'} _tag - Same as name, used internally.
 * @property {'NonceTooHigh'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code (-32000), standard Ethereum JSON-RPC error code for server errors.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class NonceTooHighError extends BaseError {
    /**
     * Constructs a NonceTooHighError.
     *
     * @param {string} message - Human-readable error message.
     * @param {NonceTooHighErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='NonceTooHigh'] - The tag for the error.
     */
    constructor(message: string, args?: NonceTooHighErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a NonceTooHighError.
 */
type NonceTooHighErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a NonceTooLowError.
 * @typedef {Object} NonceTooLowErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the nonce value is too low for a transaction.
 *
 * This error is typically encountered when a transaction is submitted with a nonce that is lower
 * than the current nonce for the sender's account. In Ethereum, nonces are used to ensure
 * transactions are processed in the correct order and to prevent double-spending.
 *
 * The error code -32000 is a standard Ethereum JSON-RPC error code indicating a generic server error,
 * which is often used for various transaction-related errors including nonce issues.
 *
 * @example
 * try {
 *   await client.sendTransaction({
 *     from: '0x1234567890123456789012345678901234567890',
 *     to: '0x0987654321098765432109876543210987654321',
 *     value: '0x1',
 *     nonce: 5 // Assuming this nonce is too low
 *   })
 * } catch (error) {
 *   if (error instanceof NonceTooLowError) {
 *     console.error('Nonce too low:', error.message);
 *     console.log('Try increasing the nonce or use `await client.getTransactionCount(address)` to get the correct nonce');
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {NonceTooLowErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'NonceTooLow'} _tag - Same as name, used internally.
 * @property {'NonceTooLow'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code (-32000), standard Ethereum JSON-RPC error code for server errors.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class NonceTooLowError extends BaseError {
    /**
     * Constructs a NonceTooLowError.
     *
     * @param {string} message - Human-readable error message.
     * @param {NonceTooLowErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='NonceTooLow'] - The tag for the error.
     */
    constructor(message: string, args?: NonceTooLowErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a NonceTooLowError.
 */
type NonceTooLowErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a ParseError.
 * @typedef {Object} ParseErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when invalid JSON is received by the server, resulting in a parsing error.
 *
 * This error is typically encountered when a JSON-RPC request is malformed or the JSON syntax is incorrect.
 * It's a standard JSON-RPC error with code -32700, indicating issues at the protocol level rather than
 * the application level.
 *
 * @example
 * try {
 *   await client.request({
 *     method: 'eth_getBalance',
 *     params: ['0x1234567890123456789012345678901234567890', 'latest'],
 *     // Imagine this request is somehow malformed JSON
 *   })
 * } catch (error) {
 *   if (error instanceof ParseError) {
 *     console.error('JSON-RPC parse error:', error.message);
 *     console.log('Check the request format and try again');
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {ParseErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'ParseError'} _tag - Same as name, used internally.
 * @property {'ParseError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code (-32700), standard JSON-RPC error code for parse errors.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class ParseError extends BaseError {
    /**
     * The error code for ParseError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs a ParseError.
     *
     * @param {string} message - Human-readable error message.
     * @param {ParseErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='ParseError'] - The tag for the error.
     */
    constructor(message: string, args?: ParseErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a ParseError.
 */
type ParseErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a PendingTransactionTimeoutError.
 * @typedef {Object} PendingTransactionTimeoutErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when a transaction is still pending and has not been included in a block.
 *
 * This error is typically encountered when a transaction takes too long to be confirmed.
 *
 * @example
 * try {
 *   // Some operation that can throw a PendingTransactionTimeoutError
 * } catch (error) {
 *   if (error instanceof PendingTransactionTimeoutError) {
 *     console.error(error.message);
 *     // Handle the pending transaction timeout error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {PendingTransactionTimeoutErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'PendingTransactionTimeout'} _tag - Same as name, used internally.
 * @property {'PendingTransactionTimeout'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class PendingTransactionTimeoutError extends BaseError {
    /**
     * The error code for PendingTransactionTimeoutError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs a PendingTransactionTimeoutError.
     *
     * @param {string} message - Human-readable error message.
     * @param {PendingTransactionTimeoutErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='PendingTransactionTimeout'] - The tag for the error.
     */
    constructor(message: string, args?: PendingTransactionTimeoutErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a PendingTransactionTimeoutError.
 */
type PendingTransactionTimeoutErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a RateLimitExceededError.
 * @typedef {Object} RateLimitExceededErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the rate limit has been exceeded.
 *
 * This error is typically encountered when a user or application exceeds the allowed number of requests within a certain timeframe.
 *
 * @example
 * try {
 *   // Some operation that can throw a RateLimitExceededError
 * } catch (error) {
 *   if (error instanceof RateLimitExceededError) {
 *     console.error(error.message);
 *     // Handle the rate limit exceeded error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {RateLimitExceededErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'RateLimitExceeded'} _tag - Same as name, used internally.
 * @property {'RateLimitExceeded'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class RateLimitExceededError extends BaseError {
    /**
     * Constructs a RateLimitExceededError.
     *
     * @param {string} message - Human-readable error message.
     * @param {RateLimitExceededErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='RateLimitExceeded'] - The tag for the error.
     */
    constructor(message: string, args?: RateLimitExceededErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a RateLimitExceededError.
 */
type RateLimitExceededErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a ResourceNotFoundError.
 * @typedef {Object} ResourceNotFoundErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the requested resource was not found on the Ethereum node.
 *
 * This error is typically encountered when a JSON-RPC request is made for a resource that does not exist or is not available.
 *
 * @example
 * try {
 *   // Some operation that can throw a ResourceNotFoundError
 * } catch (error) {
 *   if (error instanceof ResourceNotFoundError) {
 *     console.error(error.message);
 *     // Handle the resource not found error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {ResourceNotFoundErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'ResourceNotFound'} _tag - Same as name, used internally.
 * @property {'ResourceNotFound'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class ResourceNotFoundError extends BaseError {
    /**
     * Constructs a ResourceNotFoundError.
     *
     * @param {string} message - Human-readable error message.
     * @param {ResourceNotFoundErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='ResourceNotFound'] - The tag for the error.
     */
    constructor(message: string, args?: ResourceNotFoundErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a ResourceNotFoundError.
 */
type ResourceNotFoundErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a ResourceUnavailableError.
 * @typedef {Object} ResourceUnavailableErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the requested resource is temporarily unavailable.
 *
 * This error is typically encountered when a JSON-RPC request is made for a resource that is temporarily unavailable due to server issues or other reasons.
 *
 * @example
 * try {
 *   // Some operation that can throw a ResourceUnavailableError
 * } catch (error) {
 *   if (error instanceof ResourceUnavailableError) {
 *     console.error(error.message);
 *     // Handle the resource unavailable error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {ResourceUnavailableErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'ResourceUnavailable'} _tag - Same as name, used internally.
 * @property {'ResourceUnavailable'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class ResourceUnavailableError extends BaseError {
    /**
     * The error code for ResourceUnavailableError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs a ResourceUnavailableError.
     *
     * @param {string} message - Human-readable error message.
     * @param {ResourceUnavailableErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='ResourceUnavailable'] - The tag for the error.
     */
    constructor(message: string, args?: ResourceUnavailableErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a ResourceUnavailableError.
 */
type ResourceUnavailableErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a RevertError.
 * @typedef {Object} RevertErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('@ethereumjs/evm').EVMError|BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when a transaction or message call is reverted.
 *
 * This error is typically encountered when a contract explicitly calls the `revert`
 * operation or when a condition in a `require` statement is not met. It's a way for
 * smart contracts to signal that an operation should be rolled back due to a failure
 * condition.
 *
 * The error code -32000 is a standard Ethereum JSON-RPC error code indicating a
 * generic server error, which is often used for revert errors.
 *
 * @example
 * try {
 *   const result = await client.call({
 *     to: '0x742d35Cc6634C0532925a3b844Bc454e4438f44e',
 *     data: '0x...' // encoded function call that might revert
 *   })
 * } catch (error) {
 *   if (error instanceof RevertError) {
 *     console.error('Transaction reverted:', error.message);
 *     console.log('Revert reason:', error.data); // If available
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {RevertErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {string} _tag - Same as name, used internally.
 * @property {string} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code (-32000), standard Ethereum JSON-RPC error code for server errors.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class RevertError extends BaseError {
    /**
     * The error code for RevertError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs a RevertError.
     *
     * @param {string} message - Human-readable error message.
     * @param {RevertErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='RevertError'] - The tag for the error.
     */
    constructor(message: string, args?: RevertErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a RevertError.
 */
type RevertErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: _ethereumjs_evm.EVMError | BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a TransactionRejectedError.
 * @typedef {Object} TransactionRejectedErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when a transaction is rejected by the Ethereum node.
 *
 * This error is typically encountered when a transaction fails validation or other checks by the node.
 *
 * @example
 * try {
 *   // Some operation that can throw a TransactionRejectedError
 * } catch (error) {
 *   if (error instanceof TransactionRejectedError) {
 *     console.error(error.message);
 *     // Handle the transaction rejected error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {TransactionRejectedErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'TransactionRejected'} _tag - Same as name, used internally.
 * @property {'TransactionRejected'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class TransactionRejectedError extends BaseError {
    /**
     * The error code for TransactionRejectedError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs a TransactionRejectedError.
     *
     * @param {string} message - Human-readable error message.
     * @param {TransactionRejectedErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='TransactionRejected'] - The tag for the error.}
     */
    constructor(message: string, args?: TransactionRejectedErrorParameters, tag?: string);
    /**
     * @type {object|undefined}
     */
    meta: object | undefined;
    /**
     * @type {'TransactionRejected'}
     * @override
     */
    override _tag: "TransactionRejected";
    /**
     * @type {'TransactionRejected'}
     * @override
     */
    override name: "TransactionRejected";
}
/**
 * Parameters for constructing a TransactionRejectedError.
 */
type TransactionRejectedErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a TransactionTooLargeError.
 * @typedef {Object} TransactionTooLargeErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when a transaction is too large.
 *
 * This error is typically encountered when a transaction exceeds the maximum allowed size.
 *
 * @example
 * try {
 *   // Some operation that can throw a TransactionTooLargeError
 * } catch (error) {
 *   if (error instanceof TransactionTooLargeError) {
 *     console.error(error.message);
 *     // Handle the transaction too large error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {TransactionTooLargeErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'TransactionTooLarge'} _tag - Same as name, used internally.
 * @property {'TransactionTooLarge'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class TransactionTooLargeError extends BaseError {
    /**
     * The error code for TransactionTooLargeError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs a TransactionTooLargeError.
     *
     * @param {string} message - Human-readable error message.
     * @param {TransactionTooLargeErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='TransactionTooLargeError'] - The tag for the error.
     */
    constructor(message: string, args?: TransactionTooLargeErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a TransactionTooLargeError.
 */
type TransactionTooLargeErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a TransactionUnderpricedError.
 * @typedef {Object} TransactionUnderpricedErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the transaction gas price is too low.
 *
 * This error is typically encountered when a transaction is submitted with a gas price that is below the acceptable threshold.
 *
 * @example
 * try {
 *   // Some operation that can throw a TransactionUnderpricedError
 * } catch (error) {
 *   if (error instanceof TransactionUnderpricedError) {
 *     console.error(error.message);
 *     // Handle the transaction underpriced error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {TransactionUnderpricedErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'TransactionUnderpriced'} _tag - Same as name, used internally.
 * @property {'TransactionUnderpriced'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class TransactionUnderpricedError extends BaseError {
    /**
     * The error code for TransactionUnderpricedError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs a TransactionUnderpricedError.
     *
     * @param {string} message - Human-readable error message.
     * @param {TransactionUnderpricedErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='TransactionUnderpriced'] - The tag for the error.
     */
    constructor(message: string, args?: TransactionUnderpricedErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a TransactionUnderpricedError.
 */
type TransactionUnderpricedErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an UnknownBlockError.
 * @typedef {Object} UnknownBlockErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the specified block could not be found.
 *
 * This error is typically encountered when a block hash or number is provided that does not correspond
 * to any block known to the node. This can happen if the block hasn't been mined yet, if it's on a
 * different chain, or if the node is not fully synced.
 *
 * The error code -32001 is a non-standard extension used by some Ethereum clients to
 * indicate this specific condition.
 *
 * @example
 * try {
 *   const block = await client.getBlock({
 *     blockHash: '0x1234567890123456789012345678901234567890123456789012345678901234'
 *   })
 * } catch (error) {
 *   if (error instanceof UnknownBlockError) {
 *     console.error('Unknown block:', error.message);
 *     console.log('The specified block does not exist or is not available to this node');
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {UnknownBlockErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'UnknownBlock'} _tag - Same as name, used internally.
 * @property {'UnknownBlock'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code (-32001), a non-standard extension for this specific error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class UnknownBlockError extends BaseError {
    /**
     * The error code for UnknownBlockError.
     * @type {number}
     */
    static code: number;
    /**
     * Constructs an UnknownBlockError.
     *
     * @param {string} message - Human-readable error message.
     * @param {UnknownBlockErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='UnknownBlock'] - The tag for the error.
     */
    constructor(message: string, args?: UnknownBlockErrorParameters, tag?: string);
}
/**
 * Parameters for constructing an UnknownBlockError.
 */
type UnknownBlockErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an UnsupportedChainError.
 * @typedef {Object} UnsupportedChainErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the specified chain is not supported.
 *
 * This error is typically encountered when a chain ID is provided that is not supported by the node or application.
 *
 * @example
 * try {
 *   // Some operation that can throw an UnsupportedChainError
 * } catch (error) {
 *   if (error instanceof UnsupportedChainError) {
 *     console.error(error.message);
 *     // Handle the unsupported chain error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {UnsupportedChainErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'UnsupportedChain'} _tag - Same as name, used internally.
 * @property {'UnsupportedChain'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class UnsupportedChainError extends BaseError {
    /**
     * Constructs an UnsupportedChainError.
     *
     * @param {string} message - Human-readable error message.
     * @param {UnsupportedChainErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='UnsupportedChain'] - The tag for the error.
     */
    constructor(message: string, args?: UnsupportedChainErrorParameters, tag?: string);
}
/**
 * Parameters for constructing an UnsupportedChainError.
 */
type UnsupportedChainErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | Error;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an AccountNotFoundError.
 * @typedef {Object} AccountNotFoundErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('./BaseError.js').BaseError|Error} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when an account cannot be found in the state.
 *
 * This error is typically encountered when a transaction or operation references an account that does not exist in the blockchain state.
 *
 * @example
 * try {
 *   // Some operation that can throw an AccountNotFoundError
 * } catch (error) {
 *   if (error instanceof AccountNotFoundError) {
 *     console.error(error.message);
 *     // Handle the account not found error
 *   }
 * }
 *
 * @param {string} message - A human-readable error message.
 * @param {AccountNotFoundErrorParameters} [args={}] - Additional parameters for the ResourceNotFoundError.
 * @property {'AccountNotFoundError'} _tag - Same as name, used internally.
 * @property {'AccountNotFoundError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class AccountNotFoundError extends ResourceNotFoundError {
}

/**
 * Parameters for constructing a {@link AuthCallUnsetError}.
 * @typedef {Object} AuthCallUnsetErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an EIP-3074 specific error that occurs when attempting to AUTHCALL without AUTH set.
 *
 * AuthCallUnset errors can occur due to:
 * - Attempting to execute an AUTHCALL without setting the necessary authorization.
 *
 * To debug an AuthCallUnset error:
 * 1. **Review Authorization Logic**: Ensure that the necessary authorization is set before executing an AUTHCALL.
 * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the AUTHCALL is attempted without AUTH set.
 *
 * @example
 * ```typescript
 * import { AuthCallUnsetError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an AuthCallUnsetError
 * } catch (error) {
 *   if (error instanceof AuthCallUnsetError) {
 *     console.error(error.message);
 *     // Handle the AuthCallUnset error
 *   }
 * }
 * ```
 *
 * @param {string} [message='AuthCallUnset error occurred.'] - A human-readable error message.
 * @param {AuthCallUnsetErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'AuthCallUnsetError'} _tag - Same as name, used internally.
 * @property {'AuthCallUnsetError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class AuthCallUnsetError extends ExecutionError {
    /** @type {string} */ /**
     * Constructs an AuthCallUnsetError.
     * Represents an EIP-3074 specific error that occurs when attempting to AUTHCALL without AUTH set.
     *
     * AuthCallUnset errors can occur due to:
     * - Attempting to execute an AUTHCALL without setting the necessary authorization.
     *
     * To debug an AuthCallUnset error:
     * 1. **Review Authorization Logic**: Ensure that the necessary authorization is set before executing an AUTHCALL.
     * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the AUTHCALL is attempted without AUTH set.
     *
     * @param {string} [message='AuthCallUnset error occurred.'] - Human-readable error message.
     * @param {AuthCallUnsetErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='AuthCallUnsetError'] - The tag for the error.
     */
    constructor(message?: string, args?: AuthCallUnsetErrorParameters, tag?: string);
    /**
     * @type {object|undefined}
     */
    meta: object | undefined;
}
/**
 * Parameters for constructing a {@link AuthCallUnsetError}.
 */
type AuthCallUnsetErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link BLS12381FpNotInFieldError}.
 * @typedef {Object} BLS12381FpNotInFieldErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an EIP-2537 specific error that occurs when an fp point is not in the field during BLS12-381 operations.
 *
 * Fp point not in field errors can occur due to:
 * - Providing an fp point that does not lie within the expected field for BLS12-381 operations.
 *
 * @example
 * ```typescript
 * import { BLS12381FpNotInFieldError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw a BLS12381FpNotInFieldError
 * } catch (error) {
 *   if (error instanceof BLS12381FpNotInFieldError) {
 *     console.error(error.message);
 *     // Handle the fp point not in field error
 *   }
 * }
 * ```
 *
 * @param {string} [message='BLS12-381 fp point not in field error occurred.'] - A human-readable error message.
 * @param {BLS12381FpNotInFieldErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'BLS12381FpNotInFieldError'} _tag - Same as name, used internally.
 * @property {'BLS12381FpNotInFieldError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class BLS12381FpNotInFieldError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs a BLS12381FpNotInFieldError.
     * Represents an EIP-2537 specific error that occurs when an fp point is not in the field during BLS12-381 operations.
     *
     * Fp point not in field errors can occur due to:
     * - Providing an fp point that does not lie within the expected field for BLS12-381 operations.
     *
     *
     * @param {string} [message='BLS12-381 fp point not in field error occurred.'] - Human-readable error message.
     * @param {BLS12381FpNotInFieldErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='BLS12381FpNotInFieldError'] - The tag for the error.
     */
    constructor(message?: string, args?: BLS12381FpNotInFieldErrorParameters, tag?: string);
    /**
     * @type {object|undefined}
     */
    meta: object | undefined;
}
/**
 * Parameters for constructing a {@link BLS12381FpNotInFieldError}.
 */
type BLS12381FpNotInFieldErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link BLS12381InputEmptyError}.
 * @typedef {Object} BLS12381InputEmptyErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an EIP-2537 specific error that occurs when an input is empty during BLS12-381 operations.
 *
 * Input empty errors can occur due to:
 * - Providing empty input data for BLS12-381 operations.
 *
 * @example
 * ```typescript
 * import { BLS12381InputEmptyError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw a BLS12381InputEmptyError
 * } catch (error) {
 *   if (error instanceof BLS12381InputEmptyError) {
 *     console.error(error.message);
 *     // Handle the input empty error
 *   }
 * }
 * ```
 *
 * @param {string} [message='BLS12-381 input empty error occurred.'] - A human-readable error message.
 * @param {BLS12381InputEmptyErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'BLS12381InputEmptyError'} _tag - Same as name, used internally.
 * @property {'BLS12381InputEmptyError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class BLS12381InputEmptyError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs a BLS12381InputEmptyError.
     * Represents an EIP-2537 specific error that occurs when an input is empty during BLS12-381 operations.
     *
     * Input empty errors can occur due to:
     * - Providing empty input data for BLS12-381 operations.
     *
     *
     * @param {string} [message='BLS12-381 input empty error occurred.'] - Human-readable error message.
     * @param {BLS12381InputEmptyErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='BLS12381InputEmptyError'] - The tag for the error.
     */
    constructor(message?: string, args?: BLS12381InputEmptyErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link BLS12381InputEmptyError}.
 */
type BLS12381InputEmptyErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link BLS12381InvalidInputLengthError}.
 * @typedef {Object} BLS12381InvalidInputLengthErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an EIP-2537 specific error that occurs when an invalid input length is encountered during BLS12-381 operations.
 *
 * Invalid input length errors can occur due to:
 * - Providing input data of incorrect length for BLS12-381 operations.
 *
 * @example
 * ```typescript
 * import { BLS12381InvalidInputLengthError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw a BLS12381InvalidInputLengthError
 * } catch (error) {
 *   if (error instanceof BLS12381InvalidInputLengthError) {
 *     console.error(error.message);
 *     // Handle the invalid input length error
 *   }
 * }
 * ```
 *
 * @param {string} [message='BLS12-381 invalid input length error occurred.'] - A human-readable error message.
 * @param {BLS12381InvalidInputLengthErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'BLS12381InvalidInputLengthError'} _tag - Same as name, used internally.
 * @property {'BLS12381InvalidInputLengthError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class BLS12381InvalidInputLengthError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs a BLS12381InvalidInputLengthError.
     * Represents an EIP-2537 specific error that occurs when an invalid input length is encountered during BLS12-381 operations.
     *
     * Invalid input length errors can occur due to:
     * - Providing input data of incorrect length for BLS12-381 operations.
     *
     *
     * @param {string} [message='BLS12-381 invalid input length error occurred.'] - Human-readable error message.
     * @param {BLS12381InvalidInputLengthErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='BLS12381InvalidInputLengthError'] - The tag for the error.
     */
    constructor(message?: string, args?: BLS12381InvalidInputLengthErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link BLS12381InvalidInputLengthError}.
 */
type BLS12381InvalidInputLengthErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link BLS12381PointNotOnCurveError}.
 * @typedef {Object} BLS12381PointNotOnCurveErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an EIP-2537 specific error that occurs when a point is not on the curve during BLS12-381 operations.
 *
 * Point not on curve errors can occur due to:
 * - Providing a point that does not lie on the expected curve for BLS12-381 operations.
 *
 * @example
 * ```typescript
 * import { BLS12381PointNotOnCurveError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw a BLS12381PointNotOnCurveError
 * } catch (error) {
 *   if (error instanceof BLS12381PointNotOnCurveError) {
 *     console.error(error.message);
 *     // Handle the point not on curve error
 *   }
 * }
 * ```
 *
 * @param {string} [message='BLS12-381 point not on curve error occurred.'] - A human-readable error message.
 * @param {BLS12381PointNotOnCurveErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'BLS12381PointNotOnCurveError'} _tag - Same as name, used internally.
 * @property {'BLS12381PointNotOnCurveError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class BLS12381PointNotOnCurveError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs a BLS12381PointNotOnCurveError.
     * Represents an EIP-2537 specific error that occurs when a point is not on the curve during BLS12-381 operations.
     *
     * Point not on curve errors can occur due to:
     * - Providing a point that does not lie on the expected curve for BLS12-381 operations.
     *
     * @param {string} [message='BLS12-381 point not on curve error occurred.'] - Human-readable error message.
     * @param {BLS12381PointNotOnCurveErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='BLS12381PointNotOnCurveError'] - The tag for the error.
     */
    constructor(message?: string, args?: BLS12381PointNotOnCurveErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link BLS12381PointNotOnCurveError}.
 */
type BLS12381PointNotOnCurveErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link CodeStoreOutOfGasError}.
 * @typedef {Object} CodeStoreOutOfGasErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {GasLimitExceededError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when a transaction runs out of gas during code storage.
 * This error is typically encountered when the gas provided for storing code is insufficient to complete its execution.
 * EVM transaction execution metadata level error
 *
 * Code store out of gas errors can occur due to:
 * - Insufficient gas provided for storing large contracts.
 * - Incorrect estimation of gas required for storing code.
 * - Contracts with high gas consumption during the deployment phase.
 * - Non-deterministic gas usage during code storage.
 * - If TEVM submitted the transaction using `createTransaction: true` and the account being used runs out of gas.
 *
 * To debug a code store out of gas error:
 * 1. **Review Gas Estimates**: Ensure that the gas estimate for your transaction is accurate and sufficient, especially for large contracts. If you provided explicit gas-related parameters, double-check their values.
 * 2. **Optimize Contract Code**: Refactor your smart contract code to reduce gas consumption during deployment. Consider simplifying complex initialization code.
 * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the deployment process and inspect gas usage.
 * 4. **Estimate Gas Multiple Times**: If using TEVM gas estimations, it might make sense to estimate gas many times and take the worst case to set `gasPrice`. Most nodes execute `eth_estimateGas` 10 times, while TEVM runs it only once.
 * 5. **Use Other Tools**: Use other tools such as [Foundry](https://book.getfoundry.sh/forge/gas). If it works in Foundry, consider [opening a bug report](https://github.com/ethereumjs/ethereumjs-monorepo/issues).
 *
 * @example
 * ```typescript
 * import { CodeStoreOutOfGasError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw a CodeStoreOutOfGasError
 * } catch (error) {
 *   if (error instanceof CodeStoreOutOfGasError) {
 *     console.error(error.message);
 *     // Handle the code store out of gas error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Code store out of gas error occurred.'] - A human-readable error message.
 * @param {CodeStoreOutOfGasErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'CodeStoreOutOfGasError'} _tag - Same as name, used internally.
 * @property {'CodeStoreOutOfGasError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class CodeStoreOutOfGasError extends GasLimitExceededError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs a CodeStoreOutOfGasError.
     * Represents an error that occurs when a transaction runs out of gas during code storage.
     * This error is typically encountered when the gas provided for storing code is insufficient to complete its execution.
     * EVM transaction execution metadata level error
     *
     * Code store out of gas errors can occur due to:
     * - Insufficient gas provided for storing large contracts.
     * - Incorrect estimation of gas required for storing code.
     * - Contracts with high gas consumption during the deployment phase.
     * - Non-deterministic gas usage during code storage.
     * - If TEVM submitted the transaction using `createTransaction: true` and the account being used runs out of gas.
     *
     * @param {string} [message='Code store out of gas error occurred.'] - Human-readable error message.
     * @param {CodeStoreOutOfGasErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='CodeStoreOutOfGasError'] - The tag for the error.
     */
    constructor(message?: string, args?: CodeStoreOutOfGasErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link CodeStoreOutOfGasError}.
 */
type CodeStoreOutOfGasErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: GasLimitExceededError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link CodeSizeExceedsMaximumError}.
 * @typedef {Object} CodeSizeExceedsMaximumErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {GasLimitExceededError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an calldata/creation error that occurs when the code size exceeds the maximum limit.
 * This error is typically encountered when the contract size to be deployed exceeds the maximum allowed size.
 *
 * Code size exceeds maximum errors can occur due to:
 * - Deployment of contracts with large bytecode.
 * - Contracts with a significant amount of embedded data or logic.
 * - Incorrect settings for contract size limits in TEVM configuration.
 *
 * To debug a code size exceeds maximum error:
 * 1. **Review Contract Size**: Ensure that the contract bytecode size is within the allowed limits. Consider refactoring the contract to reduce its size.
 * 2. **Optimize Contract Code**: Break down large contracts into smaller, modular contracts and use libraries or inheritance to share code.
 * 3. **Configure TEVM Memory Client**: When creating a TEVM MemoryClient instance, set `allowUnlimitedContractSize` to `true` if necessary. Note that even with this setting, you may still encounter block limits.
 *    ```typescript
 *    import { createMemoryClient } from 'tevm'
 *
 *    const client = createMemoryClient({ allowUnlimitedContractSize: true })
 *    ```
 * 4. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract deployment process and inspect the bytecode size.
 * 5. **Use Other Tools**: Use other tools to analyze and optimize contract bytecode.
 *
 * @example
 * ```typescript
 * import { CodeSizeExceedsMaximumError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw a CodeSizeExceedsMaximumError
 * } catch (error) {
 *   if (error instanceof CodeSizeExceedsMaximumError) {
 *     console.error(error.message);
 *     // Handle the code size exceeds maximum error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Code size exceeds maximum error occurred.'] - A human-readable error message.
 * @param {CodeSizeExceedsMaximumErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'CodeSizeExceedsMaximumError'} _tag - Same as name, used internally.
 * @property {'CodeSizeExceedsMaximumError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class CodeSizeExceedsMaximumError extends GasLimitExceededError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs a CodeSizeExceedsMaximumError.
     * Represents an calldata/creation error that occurs when the code size exceeds the maximum limit.
     * This error is typically encountered when the contract size to be deployed exceeds the maximum allowed size.
     *
     * Code size exceeds maximum errors can occur due to:
     * - Deployment of contracts with large bytecode.
     * - Contracts with a significant amount of embedded data or logic.
     * - Incorrect settings for contract size limits in TEVM configuration.
     *
     * To debug a code size exceeds maximum error:
     * 1. **Review Contract Size**: Ensure that the contract bytecode size is within the allowed limits. Consider refactoring the contract to reduce its size.
     * 2. **Optimize Contract Code**: Break down large contracts into smaller, modular contracts and use libraries or inheritance to share code.
     * 3. **Configure TEVM Memory Client**: When creating a TEVM MemoryClient instance, set `allowUnlimitedContractSize` to `true` if necessary. Note that even with this setting, you may still encounter block limits.
     *    ```typescript
     *    import { createMemoryClient } from 'tevm'
     *
     *    const client = createMemoryClient({ allowUnlimitedContractSize: true })
     *    ```
     * 4. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract deployment process and inspect the bytecode size.
     * 5. **Use Other Tools**: Use other tools to analyze and optimize contract bytecode.
     *
     *
     * @param {string} [message='Code size exceeds maximum error occurred.'] - Human-readable error message.
     * @param {CodeSizeExceedsMaximumErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='CodeSizeExceedsMaximumError'] - The tag for the error.
     */
    constructor(message?: string, args?: CodeSizeExceedsMaximumErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link CodeSizeExceedsMaximumError}.
 */
type CodeSizeExceedsMaximumErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: GasLimitExceededError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link CreateCollisionError}.
 * @typedef {Object} CreateCollisionErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an execution error that occurs when a contract creation results in a collision.
 *
 * Create collision errors can occur due to:
 * - Attempting to deploy a contract to an address that is already in use.
 *
 * To debug a create collision error:
 * 1. **Review Deployment Logic**: Ensure that the contract address is not already in use.
 * 2. **Nonces** Check that the nonce of the account used had been incremented. Remember nonces do not update until a block is mined.
 * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the deployment process and identify the collision.
 *
 * @example
 * ```typescript
 * import { CreateCollisionError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw a CreateCollisionError
 * } catch (error) {
 *   if (error instanceof CreateCollisionError) {
 *     console.error(error.message);
 *     // Handle the create collision error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Create collision error occurred.'] - A human-readable error message.
 * @param {CreateCollisionErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'CreateCollisionError'} _tag - Same as name, used internally.
 * @property {'CreateCollisionError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class CreateCollisionError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs a CreateCollisionError.
     * Represents an execution error that occurs when a contract creation results in a collision.
     *
     * Create collision errors can occur due to:
     * - Attempting to deploy a contract to an address that is already in use.
     *
     * To debug a create collision error:
     * 1. **Review Deployment Logic**: Ensure that the contract address is not already in use.
     * 2. **Nonces** Check that the nonce of the account used had been incremented. Remember nonces do not update until a block is mined.
     * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the deployment process and identify the collision.
     *
     * @param {string} [message='Create collision error occurred.'] - Human-readable error message.
     * @param {CreateCollisionErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='CreateCollisionError'] - The tag for the error.
     */
    constructor(message?: string, args?: CreateCollisionErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link CreateCollisionError}.
 */
type CreateCollisionErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link InvalidCommitmentError}.
 * @typedef {Object} InvalidCommitmentErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an EIP-4844 specific error that occurs when a KZG commitment does not match the versioned hash.
 *
 * Invalid commitment errors can occur due to:
 * - Providing a KZG commitment that does not match the expected versioned hash.
 *
 * @example
 * ```typescript
 * import { InvalidCommitmentError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an InvalidCommitmentError
 * } catch (error) {
 *   if (error instanceof InvalidCommitmentError) {
 *     console.error(error.message);
 *     // Handle the invalid commitment error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Invalid commitment error occurred.'] - A human-readable error message.
 * @param {InvalidCommitmentErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidCommitmentError'} _tag - Same as name, used internally.
 * @property {'InvalidCommitmentError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidCommitmentError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs an InvalidCommitmentError.
     * Represents an EIP-4844 specific error that occurs when a KZG commitment does not match the versioned hash.
     *
     * Invalid commitment errors can occur due to:
     * - Providing a KZG commitment that does not match the expected versioned hash.
     *
     * @example
     * ```typescript
     * import { InvalidCommitmentError } from '@tevm/errors'
     * try {
     *   // Some operation that can throw an InvalidCommitmentError
     * } catch (error) {
     *   if (error instanceof InvalidCommitmentError) {
     *     console.error(error.message);
     *     // Handle the invalid commitment error
     *   }
     * }
     * ```
     *
     * @param {string} [message='Invalid commitment error occurred.'] - Human-readable error message.
     * @param {InvalidCommitmentErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidCommitmentError'] - The tag for the error.
     */
    constructor(message?: string, args?: InvalidCommitmentErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link InvalidCommitmentError}.
 */
type InvalidCommitmentErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link EvmRevertError}.
 * @typedef {Object} EvmRevertErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {import('@ethereumjs/evm').EVMError} [cause] - The cause of the error. From running ethereumjs EVM.runCall
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an execution error that occurs when a transaction is reverted during EVM execution.
 * This error is typically encountered when a smart contract execution is reverted due to unmet conditions or failed assertions.
 *
 * EvmRevert errors can occur due to:
 * - Failed assertions in the smart contract code.
 * - Conditions in the code that trigger a revert.
 * - Insufficient gas to complete the transaction.
 * - Contract logic that intentionally reverts under certain conditions.
 *
 * To debug a revert error:
 * 1. **Review Revert Conditions**: Ensure that the conditions in the contract code that trigger reverts are properly handled and expected.
 * 2. **Check Assertions**: Verify that all assertions in the code are valid and necessary.
 * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the revert occurs.
 * 4. **Inspect Contract Logic**: Manually inspect the contract code to understand why the revert is being triggered and ensure it is intentional.
 *
 * @example
 * ```typescript
 * import { EvmRevertError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw a EvmRevertError
 * } catch (error) {
 *   if (error instanceof EvmRevertError) {
 *     console.error(error.message);
 *     // Handle the revert error
 *   }
 * }
 * ```
 *
 * @param {string} [message='EvmRevert error occurred.'] - A human-readable error message.
 * @param {EvmRevertErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'EvmRevertError'} _tag - Same as name, used internally.
 * @property {'EvmRevertError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class EvmRevertError extends RevertError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs a EvmRevertError.
     * Represents an execution error that occurs when a transaction is reverted during EVM execution.
     * This error is typically encountered when a smart contract execution is reverted due to unmet conditions or failed assertions.
     *
     * EvmRevert errors can occur due to:
     * - Failed assertions in the smart contract code.
     * - Conditions in the code that trigger a revert.
     * - Insufficient gas to complete the transaction.
     * - Contract logic that intentionally reverts under certain conditions.
     *
     * To debug a revert error:
     * 1. **Review Revert Conditions**: Ensure that the conditions in the contract code that trigger reverts are properly handled and expected.
     * 2. **Check Assertions**: Verify that all assertions in the code are valid and necessary.
     * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the revert occurs.
     * 4. **Inspect Contract Logic**: Manually inspect the contract code to understand why the revert is being triggered and ensure it is intentional.
     *
     * @param {string} [message='Revert error occurred.'] - Human-readable error message.
     * @param {EvmRevertErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='EvmRevertError'] - The tag for the error.
     */
    constructor(message?: string, args?: EvmRevertErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link EvmRevertError}.
 */
type EvmRevertErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error. From running ethereumjs EVM.runCall
     */
    cause?: _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link InitcodeSizeViolationError}.
 * @typedef {Object} InitcodeSizeViolationErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents a calldata/creation error that occurs when initcode exceeds the maximum allowable size during EVM execution.
 *
 * Initcode size violation errors can occur due to:
 * - Bugs in the smart contract code causing the initcode to exceed the maximum size.
 * - Issues during the deployment process resulting in oversized initcode.
 *
 * To debug an initcode size violation error:
 * 1. **Review Deployment Process**: Ensure that the initcode being deployed is within the allowable size limits.
 * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract deployment and identify where the initcode size violation occurs.
 *
 * @example
 * ```typescript
 * import { InitcodeSizeViolationError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an InitcodeSizeViolationError
 * } catch (error) {
 *   if (error instanceof InitcodeSizeViolationError) {
 *     console.error(error.message);
 *     // Handle the initcode size violation error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Initcode size violation error occurred.'] - A human-readable error message.
 * @param {InitcodeSizeViolationErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InitcodeSizeViolationError'} _tag - Same as name, used internally.
 * @property {'InitcodeSizeViolationError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InitcodeSizeViolationError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs an InitcodeSizeViolationError.
     * Represents a calldata/creation error that occurs when initcode exceeds the maximum allowable size during EVM execution.
     *
     * Initcode size violation errors can occur due to:
     * - Bugs in the smart contract code causing the initcode to exceed the maximum size.
     * - Issues during the deployment process resulting in oversized initcode.
     *
     * To debug an initcode size violation error:
     * 1. **Review Deployment Process**: Ensure that the initcode being deployed is within the allowable size limits.
     * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract deployment and identify where the initcode size violation occurs.
     *
     * @param {string} [message='Initcode size violation error occurred.'] - Human-readable error message.
     * @param {InitcodeSizeViolationErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InitcodeSizeViolationError'] - The tag for the error.
     */
    constructor(message?: string, args?: InitcodeSizeViolationErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link InitcodeSizeViolationError}.
 */
type InitcodeSizeViolationErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link InsufficientBalanceError}.
 * @typedef {Object} InsufficientBalanceErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when an account has insufficient balance to perform a transaction.
 * EVM transaction execution metadata level error
 *
 * Insufficient balance errors can occur due to:
 * - Attempting to transfer or spend more funds than available in the account.
 *
 * To debug an insufficient balance error:
 * 1. **Review Account Balance**: Ensure that the account has sufficient funds to cover the transaction.
 * 2. **Check Transaction Details**: Verify the transaction amount and ensure it does not exceed the account balance.
 * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the transaction execution and identify where the insufficient balance occurs.
 *
 * @example
 * ```typescript
 * import { InsufficientBalanceError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an InsufficientBalanceError
 * } catch (error) {
 *   if (error instanceof InsufficientBalanceError) {
 *     console.error(error.message);
 *     // Handle the insufficient balance error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Insufficient balance error occurred.'] - A human-readable error message.
 * @param {InsufficientBalanceErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InsufficientBalanceError'} _tag - Same as name, used internally.
 * @property {'InsufficientBalanceError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InsufficientBalanceError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs an InsufficientBalanceError.
     * Represents an error that occurs when an account has insufficient balance to perform a transaction.
     * EVM transaction execution metadata level error
     *
     * Insufficient balance errors can occur due to:
     * - Attempting to transfer or spend more funds than available in the account.
     *
     * To debug an insufficient balance error:
     * 1. **Review Account Balance**: Ensure that the account has sufficient funds to cover the transaction.
     * 2. **Check Transaction Details**: Verify the transaction amount and ensure it does not exceed the account balance.
     * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the transaction execution and identify where the insufficient balance occurs.
     *
     * @param {string} [message='Insufficient balance error occurred.'] - Human-readable error message.
     * @param {InsufficientBalanceErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InsufficientBalanceError'] - The tag for the error.
     */
    constructor(message?: string, args?: InsufficientBalanceErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link InsufficientBalanceError}.
 */
type InsufficientBalanceErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link InternalEvmError}.
 * @typedef {Object} InternalEvmErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {BaseError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an internal error within the EVM. This error should not typically happen
 * This error is typically encountered when there is an unexpected issue within the EVM execution or client.
 *
 * Internal errors can occur due to:
 * - Bugs in the EVM implementation.
 * - Bugs in Tevm
 *
 * If you encounter this error please open an issue on the Tevm GitHub repository.
 *
 * @example
 * ```typescript
 * import { InternalEvmError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an InternalEvmError
 * } catch (error) {
 *   if (error instanceof InternalEvmError) {
 *     console.error(error.message);
 *     // Handle the internal error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Internal error occurred.'] - A human-readable error message.
 * @param {InternalEvmErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InternalEvmError'} _tag - Same as name, used internally.
 * @property {'InternalEvmError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InternalEvmError extends BaseError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs an InternalEvmError.
     * Represents an internal error within the EVM. This error should not typically happen
     * This error is typically encountered when there is an unexpected issue within the EVM execution or client.
     *
     * Internal errors can occur due to:
     * - Bugs in the EVM implementation.
     * - Bugs in Tevm
     *
     * If you encounter this error please open an issue on the Tevm GitHub repository.
     *
     * @param {string} [message='Internal error occurred.'] - Human-readable error message.
     * @param {InternalEvmErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InternalEvmError'] - The tag for the error.
     */
    constructor(message?: string, args?: InternalEvmErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link InternalEvmError}.
 */
type InternalEvmErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: BaseError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link InvalidBeginSubError}.
 * @typedef {Object} InvalidBeginSubErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an invalid bytecode/contract error that occurs when an invalid BEGINSUB operation is executed within the EVM.
 *
 * Invalid BEGINSUB errors can occur due to:
 * - Incorrect use of the BEGINSUB opcode.
 * - Bugs in the smart contract code causing invalid subroutine execution.
 *
 * To debug an invalid BEGINSUB error:
 * 1. **Review Subroutine Logic**: Ensure that the BEGINSUB opcode is used correctly within subroutine definitions.
 * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the invalid BEGINSUB occurs.
 *
 * @example
 * ```typescript
 * import { InvalidBeginSubError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an InvalidBeginSubError
 * } catch (error) {
 *   if (error instanceof InvalidBeginSubError) {
 *     console.error(error.message);
 *     // Handle the invalid BEGINSUB error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Invalid BEGINSUB error occurred.'] - A human-readable error message.
 * @param {InvalidBeginSubErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidBeginSubError'} _tag - Same as name, used internally.
 * @property {'InvalidBeginSubError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidBeginSubError extends ExecutionError {
    /** @type {string} */ /**
     * Constructs an InvalidBeginSubError.
     * Represents an invalid bytecode/contract error that occurs when an invalid BEGINSUB operation is executed within the EVM.
     *
     * Invalid BEGINSUB errors can occur due to:
     * - Incorrect use of the BEGINSUB opcode.
     * - Bugs in the smart contract code causing invalid subroutine execution.
     *
     * To debug an invalid BEGINSUB error:
     * 1. **Review Subroutine Logic**: Ensure that the BEGINSUB opcode is used correctly within subroutine definitions.
     * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the invalid BEGINSUB occurs.
     *
     * @param {string} [message='Invalid BEGINSUB error occurred.'] - Human-readable error message.
     * @param {InvalidBeginSubErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidBeginSubError'] - The tag for the error.
     */
    constructor(message?: string, args?: InvalidBeginSubErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link InvalidBeginSubError}.
 */
type InvalidBeginSubErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link InvalidBytecodeResultError}.
 * @typedef {Object} InvalidBytecodeResultErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents a calldata/creation error that occurs when invalid bytecode is deployed during EVM execution.
 *
 * Invalid bytecode result errors can occur due to:
 * - Bugs in the smart contract code causing invalid bytecode to be generated.
 * - Issues during the deployment process resulting in invalid bytecode.
 *
 * To debug an invalid bytecode result error:
 * 1. **Review Deployment Process**: Ensure that the bytecode being deployed is valid and correctly generated.
 * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract deployment and identify where the invalid bytecode is generated or deployed.
 *
 * @example
 * ```typescript
 * import { InvalidBytecodeResultError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an InvalidBytecodeResultError
 * } catch (error) {
 *   if (error instanceof InvalidBytecodeResultError) {
 *     console.error(error.message);
 *     // Handle the invalid bytecode result error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Invalid bytecode result error occurred.'] - A human-readable error message.
 * @param {InvalidBytecodeResultErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidBytecodeResultError'} _tag - Same as name, used internally.
 * @property {'InvalidBytecodeResultError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidBytecodeResultError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs an InvalidBytecodeResultError.
     * Represents a calldata/creation error that occurs when invalid bytecode is deployed during EVM execution.
     *
     * Invalid bytecode result errors can occur due to:
     * - Bugs in the smart contract code causing invalid bytecode to be generated.
     * - Issues during the deployment process resulting in invalid bytecode.
     *
     * To debug an invalid bytecode result error:
     * 1. **Review Deployment Process**: Ensure that the bytecode being deployed is valid and correctly generated.
     * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract deployment and identify where the invalid bytecode is generated or deployed.
     *
     * @param {string} [message='Invalid bytecode result error occurred.'] - Human-readable error message.
     * @param {InvalidBytecodeResultErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidBytecodeResultError'] - The tag for the error.
     */
    constructor(message?: string, args?: InvalidBytecodeResultErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link InvalidBytecodeResultError}.
 */
type InvalidBytecodeResultErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link InvalidEofFormatError}.
 * @typedef {Object} InvalidEofFormatErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when an invalid EOF format is encountered during EVM execution.
 *
 * This error is specific to EOF
 *
 * Invalid EOF format errors can occur due to:
 * - Bugs in the smart contract code causing invalid EOF format.
 * - Issues during the deployment process resulting in invalid EOF format.
 *
 * To debug an invalid EOF format error:
 * 1. **Review Deployment Process**: Ensure that the EOF format being used is valid and correctly generated.
 * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract deployment and identify where the invalid EOF format is generated or deployed.
 *
 * @example
 * ```typescript
 * import { InvalidEofFormatError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an InvalidEofFormatError
 * } catch (error) {
 *   if (error instanceof InvalidEofFormatError) {
 *     console.error(error.message);
 *     // Handle the invalid EOF format error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Invalid EOF format error occurred.'] - A human-readable error message.
 * @param {InvalidEofFormatErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidEofFormatError'} _tag - Same as name, used internally.
 * @property {'InvalidEofFormatError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidEofFormatError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs an InvalidEofFormatError.
     * Represents an error that occurs when an invalid EOF format is encountered during EVM execution.
     *
     * This error is specific to EOF
     *
     * Invalid EOF format errors can occur due to:
     * - Bugs in the smart contract code causing invalid EOF format.
     * - Issues during the deployment process resulting in invalid EOF format.
     *
     * To debug an invalid EOF format error:
     * 1. **Review Deployment Process**: Ensure that the EOF format being used is valid and correctly generated.
     * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract deployment and identify where the invalid EOF format is generated or deployed.
     *
     * @param {string} [message='Invalid EOF format error occurred.'] - Human-readable error message.
     * @param {InvalidEofFormatErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidEofFormatError'] - The tag for the error.
     */
    constructor(message?: string, args?: InvalidEofFormatErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link InvalidEofFormatError}.
 */
type InvalidEofFormatErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link InvalidInputLengthError}.
 * @typedef {Object} InvalidInputLengthErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents a calldata/creation error that occurs when an invalid input length is encountered during EVM execution.
 *
 * Invalid input length errors can occur due to:
 * - Providing input data of incorrect length.
 *
 * To debug an invalid input length error:
 * 1. **Review Input Data**: Ensure that the input data provided matches the expected length.
 * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the invalid input length is encountered.
 *
 * @example
 * ```typescript
 * import { InvalidInputLengthError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an InvalidInputLengthError
 * } catch (error) {
 *   if (error instanceof InvalidInputLengthError) {
 *     console.error(error.message);
 *     // Handle the invalid input length error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Invalid input length error occurred.'] - A human-readable error message.
 * @param {InvalidInputLengthErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidInputLengthError'} _tag - Same as name, used internally.
 * @property {'InvalidInputLengthError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidInputLengthError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs an InvalidInputLengthError.
     * Represents a calldata/creation error that occurs when an invalid input length is encountered during EVM execution.
     *
     * Invalid input length errors can occur due to:
     * - Providing input data of incorrect length.
     *
     * To debug an invalid input length error:
     * 1. **Review Input Data**: Ensure that the input data provided matches the expected length.
     * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the invalid input length is encountered.
     *
     * @param {string} [message='Invalid input length error occurred.'] - Human-readable error message.
     * @param {InvalidInputLengthErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidInputLengthError'] - The tag for the error.
     */
    constructor(message?: string, args?: InvalidInputLengthErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link InvalidInputLengthError}.
 */
type InvalidInputLengthErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link InvalidJumpError}.
 * @typedef {Object} InvalidJumpErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an invalid bytecode/contract error that occurs when an invalid JUMP operation is executed within the EVM.
 * This error is typically encountered when the jump destination in the bytecode is invalid or does not exist.
 *
 * Invalid JUMP errors can occur due to:
 * - Incorrect jump destinations in the bytecode.
 * - Bugs in the smart contract code causing jumps to non-existent locations.
 * - Conditional logic errors leading to unexpected jump destinations.
 *
 * To debug an invalid JUMP error:
 * 1. **Double Check Bytecode**: Ensure that the bytecode provided is valid.
 * 2. **Verify Common Configuration**: Ensure you are using a `common` with the correct hardfork and EIPs that support the EVM version you are targeting.
 * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the bytecode execution and identify where the invalid JUMP occurs.
 *
 * @example
 * ```typescript
 * import { InvalidJumpError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an InvalidJumpError
 * } catch (error) {
 *   if (error instanceof InvalidJumpError) {
 *     console.error(error.message);
 *     // Handle the invalid JUMP error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Invalid JUMP error occurred.'] - A human-readable error message.
 * @param {InvalidJumpErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidJumpError'} _tag - Same as name, used internally.
 * @property {'InvalidJumpError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidJumpError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs an InvalidJumpError.
     * Represents an invalid bytecode/contract error that occurs when an invalid JUMP operation is executed within the EVM.
     * This error is typically encountered when the jump destination in the bytecode is invalid or does not exist.
     *
     * Invalid JUMP errors can occur due to:
     * - Incorrect jump destinations in the bytecode.
     * - Bugs in the smart contract code causing jumps to non-existent locations.
     * - Conditional logic errors leading to unexpected jump destinations.
     *
     * To debug an invalid JUMP error:
     * 1. **Double Check Bytecode**: Ensure that the bytecode provided is valid.
     * 2. **Verify Common Configuration**: Ensure you are using a `common` with the correct hardfork and EIPs that support the EVM version you are targeting.
     * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the bytecode execution and identify where the invalid JUMP occurs.
     *
     * @param {string} [message='Invalid JUMP error occurred.'] - Human-readable error message.
     * @param {InvalidJumpErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag] - Optionally override the name/tag for the error.
     * @param {string} [tag='InvalidJumpError'] - The tag for the error.}
     */
    constructor(message?: string, args?: InvalidJumpErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link InvalidJumpError}.
 */
type InvalidJumpErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link InvalidJumpSubError}.
 * @typedef {Object} InvalidJumpSubErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an invalid bytecode/contract error that occurs when an invalid JUMPSUB operation is executed within the EVM.
 *
 * Invalid JUMPSUB errors can occur due to:
 * - Incorrect use of the JUMPSUB opcode.
 * - Bugs in the smart contract code causing invalid subroutine jumps.
 *
 * To debug an invalid JUMPSUB error:
 * 1. **Review Subroutine Logic**: Ensure that the JUMPSUB opcode is used correctly within subroutine definitions.
 * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the invalid JUMPSUB occurs.
 *
 * @example
 * ```typescript
 * import { InvalidJumpSubError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an InvalidJumpSubError
 * } catch (error) {
 *   if (error instanceof InvalidJumpSubError) {
 *     console.error(error.message);
 *     // Handle the invalid JUMPSUB error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Invalid JUMPSUB error occurred.'] - A human-readable error message.
 * @param {InvalidJumpSubErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidJumpSubError'} _tag - Same as name, used internally.
 * @property {'InvalidJumpSubError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidJumpSubError extends ExecutionError {
    /** @type {string} */ /**
     * Constructs an InvalidJumpSubError.
     * Represents an invalid bytecode/contract error that occurs when an invalid JUMPSUB operation is executed within the EVM.
     *
     * Invalid JUMPSUB errors can occur due to:
     * - Incorrect use of the JUMPSUB opcode.
     * - Bugs in the smart contract code causing invalid subroutine jumps.
     *
     * To debug an invalid JUMPSUB error:
     * 1. **Review Subroutine Logic**: Ensure that the JUMPSUB opcode is used correctly within subroutine definitions.
     * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the invalid JUMPSUB occurs.
     *
     * @param {string} [message='Invalid JUMPSUB error occurred.'] - Human-readable error message.
     * @param {InvalidJumpSubErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidJumpSubError'] - The tag for the error.}
     *
     * @example
     * ```typescript
     * import { InvalidJumpSubError } from '@tevm/errors'
     * try {
     *   // Some operation that can throw an InvalidJumpSubError
     * } catch (error) {
     *   if (error instanceof InvalidJumpSubError) {
     *     console.error(error.message);
     *     // Handle the invalid JUMPSUB error
     *   }
     * }
     * ```
     */
    constructor(message?: string, args?: InvalidJumpSubErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link InvalidJumpSubError}.
 */
type InvalidJumpSubErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link InvalidKzgInputsError}.
 * @typedef {Object} InvalidKzgInputsErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an EIP-4844 specific error that occurs when KZG inputs are invalid.
 *
 * Invalid inputs errors can occur due to:
 * - Providing invalid KZG inputs that do not meet the expected criteria.
 *
 * @example
 * ```typescript
 * import { InvalidKzgInputsError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an InvalidKzgInputsError
 * } catch (error) {
 *   if (error instanceof InvalidKzgInputsError) {
 *     console.error(error.message);
 *     // Handle the invalid inputs error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Invalid inputs error occurred.'] - A human-readable error message.
 * @param {InvalidKzgInputsErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidKzgInputsError'} _tag - Same as name, used internally.
 * @property {'InvalidKzgInputsError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidKzgInputsError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs an InvalidKzgInputsError.
     * Represents an EIP-4844 specific error that occurs when KZG inputs are invalid.
     *
     * Invalid inputs errors can occur due to:
     * - Providing invalid KZG inputs that do not meet the expected criteria.
     *
     *
     * @param {string} [message='Invalid inputs error occurred.'] - Human-readable error message.
     * @param {InvalidKzgInputsErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidKzgInputsError'] - The tag for the error.}
     */
    constructor(message?: string, args?: InvalidKzgInputsErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link InvalidKzgInputsError}.
 */
type InvalidKzgInputsErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link InvalidOpcodeError}.
 * @typedef {Object} InvalidOpcodeErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an invalid bytecode/contract error that occurs when an invalid opcode is encountered during EVM execution.
 * This error is typically encountered when the bytecode contains an opcode that is not recognized by the EVM.
 *
 * Invalid opcode errors can occur due to:
 * - Typographical errors in the bytecode.
 * - Using opcodes that are not supported by the selected EVM version or hardfork.
 *
 * To debug an invalid opcode error:
 * 1. **Review Bytecode**: Ensure that the bytecode provided is correct and does not contain any invalid opcodes.
 * 2. **Verify Common Configuration**: Ensure you are using a `common` with the correct hardfork and EIPs that support the opcodes used by your contract.
 * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the bytecode execution and identify where the invalid opcode is encountered.
 * 4. **Inspect Contract Code**: Manually inspect the contract code to ensure it compiles correctly and does not include any invalid opcodes.
 *
 * @example
 * ```typescript
 * import { InvalidOpcodeError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an InvalidOpcodeError
 * } catch (error) {
 *   if (error instanceof InvalidOpcodeError) {
 *     console.error(error.message);
 *     // Handle the invalid opcode error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Invalid opcode error occurred.'] - A human-readable error message.
 * @param {InvalidOpcodeErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidOpcodeError'} _tag - Same as name, used internally.
 * @property {'InvalidOpcodeError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidOpcodeError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs an InvalidOpcodeError.
     * Represents an invalid bytecode/contract error that occurs when an invalid opcode is encountered during EVM execution.
     * This error is typically encountered when the bytecode contains an opcode that is not recognized by the EVM.
     *
     * Invalid opcode errors can occur due to:
     * - Typographical errors in the bytecode.
     * - Using opcodes that are not supported by the selected EVM version or hardfork.
     *
     * To debug an invalid opcode error:
     * 1. **Review Bytecode**: Ensure that the bytecode provided is correct and does not contain any invalid opcodes.
     * 2. **Verify Common Configuration**: Ensure you are using a `common` with the correct hardfork and EIPs that support the opcodes used by your contract.
     * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the bytecode execution and identify where the invalid opcode is encountered.
     * 4. **Inspect Contract Code**: Manually inspect the contract code to ensure it compiles correctly and does not include any invalid opcodes.
     *
     * @param {string} [message='Invalid opcode error occurred.'] - Human-readable error message.
     * @param {InvalidOpcodeErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidOpcodeError'] - The tag for the error.}
     */
    constructor(message?: string, args?: InvalidOpcodeErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link InvalidOpcodeError}.
 */
type InvalidOpcodeErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link InvalidProofError}.
 * @typedef {Object} InvalidProofErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an EIP-4844 specific error that occurs when a KZG proof is invalid.
 *
 * Invalid proof errors can occur due to:
 * - Providing a KZG proof that does not meet the expected criteria.
 *
 * @example
 * ```typescript
 * import { InvalidProofError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an InvalidProofError
 * } catch (error) {
 *   if (error instanceof InvalidProofError) {
 *     console.error(error.message);
 *     // Handle the invalid proof error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Invalid proof error occurred.'] - A human-readable error message.
 * @param {InvalidProofErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidProofError'} _tag - Same as name, used internally.
 * @property {'InvalidProofError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidProofError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs an InvalidProofError.
     * Represents an EIP-4844 specific error that occurs when a KZG proof is invalid.
     *
     * Invalid proof errors can occur due to:
     * - Providing a KZG proof that does not meet the expected criteria.
     *
     * @param {string} [message='Invalid proof error occurred.'] - Human-readable error message.
     * @param {InvalidProofErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidProofError'] - The tag for the error.
     */
    constructor(message?: string, args?: InvalidProofErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link InvalidProofError}.
 */
type InvalidProofErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link InvalidReturnSubError}.
 * @typedef {Object} InvalidReturnSubErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an invalid bytecode/contract error that occurs when an invalid RETURNSUB operation is executed within the EVM.
 *
 * Invalid RETURNSUB errors can occur due to:
 * - Incorrect use of the RETURNSUB opcode.
 * - Bugs in the smart contract code causing invalid subroutine returns.
 *
 * To debug an invalid RETURNSUB error:
 * 1. **Review Subroutine Logic**: Ensure that the RETURNSUB opcode is used correctly within subroutine definitions.
 * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the invalid RETURNSUB occurs.
 *
 * @example
 * ```typescript
 * import { InvalidReturnSubError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an InvalidReturnSubError
 * } catch (error) {
 *   if (error instanceof InvalidReturnSubError) {
 *     console.error(error.message);
 *     // Handle the invalid RETURNSUB error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Invalid RETURNSUB error occurred.'] - A human-readable error message.
 * @param {InvalidReturnSubErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'InvalidReturnSubError'} _tag - Same as name, used internally.
 * @property {'InvalidReturnSubError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class InvalidReturnSubError extends ExecutionError {
    /** @type {string} */ /**
     * Constructs an InvalidReturnSubError.
     * Represents an invalid bytecode/contract error that occurs when an invalid RETURNSUB operation is executed within the EVM.
     *
     * Invalid RETURNSUB errors can occur due to:
     * - Incorrect use of the RETURNSUB opcode.
     * - Bugs in the smart contract code causing invalid subroutine returns.
     *
     * To debug an invalid RETURNSUB error:
     * 1. **Review Subroutine Logic**: Ensure that the RETURNSUB opcode is used correctly within subroutine definitions.
     * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the invalid RETURNSUB occurs.
     *
     * @param {string} [message='Invalid RETURNSUB error occurred.'] - Human-readable error message.
     * @param {InvalidReturnSubErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='InvalidReturnSubError'] - The tag for the error.
     */
    constructor(message?: string, args?: InvalidReturnSubErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link InvalidReturnSubError}.
 */
type InvalidReturnSubErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an OutOfGasError.
 * @typedef {Object} OutOfGasErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {GasLimitExceededError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an execution error that occurs when a transaction runs out of gas during execution.
 * This error is typically encountered when the gas provided for a transaction is insufficient to complete its execution.
 *
 * Out of gas errors can occur due to:
 * - Insufficient gas provided for complex transactions or loops.
 * - Incorrect estimation of gas required for certain operations.
 * - Contracts with high gas consumption in specific functions.
 * - Non-deterministic gas usage in contracts.
 * - If TEVM submitted the transaction using `createTransaction: true` and the account being used runs out of gas.
 *
 * To debug an out of gas error:
 * 1. **Review Gas Estimates**: Ensure that the gas estimate for your transaction is accurate and sufficient. If you provided explicit gas-related parameters, double-check their values.
 * 2. **Optimize Contract Code**: Refactor your smart contract code to reduce gas consumption, especially in loops and complex operations. Remove potential non-deterministic behaviors.
 * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the transaction and inspect gas usage.
 * 4. **Estimate Gas Multiple Times**: If using TEVM gas estimations, it might make sense to estimate gas many times and take the worst case to set `gasPrice`. Most nodes execute `eth_estimateGas` 10 times, while TEVM runs it only once.
 * 5. **Use Other Tools**: Use other tools with gas profiling such as [Foundry](https://book.getfoundry.sh/forge/gas).
 *
 * @example
 * ```typescript
 * try {
 *   // Some operation that can throw an OutOfGasError
 * } catch (error) {
 *   if (error instanceof OutOfGasError) {
 *     console.error(error.message);
 *     // Handle the out of gas error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Out of gas error occurred.'] - A human-readable error message.
 * @param {OutOfGasErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'OutOfGasError'} _tag - Same as name, used internally.
 * @property {'OutOfGasError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class OutOfGasError extends GasLimitExceededError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs an OutOfGasError.
     * Represents an execution error that occurs when a transaction runs out of gas during execution.
     * This error is typically encountered when the gas provided for a transaction is insufficient to complete its execution.
     *
     * Out of gas errors can occur due to:
     * - Insufficient gas provided for complex transactions or loops.
     * - Incorrect estimation of gas required for certain operations.
     * - Contracts with high gas consumption in specific functions.
     * - Non-deterministic gas usage in contracts.
     * - If TEVM submitted the transaction using `createTransaction: true` and the account being used runs out of gas.
     *
     * To debug an out of gas error:
     * 1. **Review Gas Estimates**: Ensure that the gas estimate for your transaction is accurate and sufficient. If you provided explicit gas-related parameters, double-check their values.
     * 2. **Optimize Contract Code**: Refactor your smart contract code to reduce gas consumption, especially in loops and complex operations. Remove potential non-deterministic behaviors.
     * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the transaction and inspect gas usage.
     * 4. **Estimate Gas Multiple Times**: If using TEVM gas estimations, it might make sense to estimate gas many times and take the worst case to set `gasPrice`. Most nodes execute `eth_estimateGas` 10 times, while TEVM runs it only once.
     * 5. **Use Other Tools**: Use other tools with gas profiling such as [Foundry](https://book.getfoundry.sh/forge/gas).
     *
     * @param {string} [message='Out of gas error occurred.'] - Human-readable error message.
     * @param {OutOfGasErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='OutOfGasError'] - The tag for the error.
     */
    constructor(message?: string, args?: OutOfGasErrorParameters, tag?: string);
}
/**
 * Parameters for constructing an OutOfGasError.
 */
type OutOfGasErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: GasLimitExceededError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link OutOfRangeError}.
 * @typedef {Object} OutOfRangeErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an invalid bytecode/contract error that occurs when a value is out of the allowable range during EVM execution.
 * This error is typically encountered when an operation results in a value that exceeds the allowed limits.
 *
 * Value out of range errors can occur due to:
 * - Arithmetic operations that result in overflow or underflow.
 * - Incorrect handling of large numbers in the smart contract code.
 * - Bugs in the smart contract code causing values to exceed their expected range.
 *
 * To debug a value out of range error:
 * 1. **Review Arithmetic Operations**: Ensure that arithmetic operations in the contract are correctly handling large numbers and preventing overflow/underflow.
 * 2. **Check Value Assignments**: Verify that values assigned to variables are within the allowable range and properly validated.
 * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the value goes out of range.
 * 4. **Inspect Contract Logic**: Manually inspect the contract code to ensure that all value assignments and operations are within the expected limits.
 *
 * @example
 * ```typescript
 * import { OutOfRangeError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw an OutOfRangeError
 * } catch (error) {
 *   if (error instanceof OutOfRangeError) {
 *     console.error(error.message);
 *     // Handle the value out of range error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Value out of range error occurred.'] - A human-readable error message.
 * @param {OutOfRangeErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'OutOfRangeError'} _tag - Same as name, used internally.
 * @property {'OutOfRangeError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class OutOfRangeError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs an OutOfRangeError.
     * Represents an invalid bytecode/contract error that occurs when a value is out of the allowable range during EVM execution.
     * This error is typically encountered when an operation results in a value that exceeds the allowed limits.
     *
     * Value out of range errors can occur due to:
     * - Arithmetic operations that result in overflow or underflow.
     * - Incorrect handling of large numbers in the smart contract code.
     * - Bugs in the smart contract code causing values to exceed their expected range.
     *
     * To debug a value out of range error:
     * 1. **Review Arithmetic Operations**: Ensure that arithmetic operations in the contract are correctly handling large numbers and preventing overflow/underflow.
     * 2. **Check Value Assignments**: Verify that values assigned to variables are within the allowable range and properly validated.
     * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the value goes out of range.
     * 4. **Inspect Contract Logic**: Manually inspect the contract code to ensure that all value assignments and operations are within the expected limits.
     *
     * @param {string} [message='Value out of range error occurred.'] - Human-readable error message.
     * @param {OutOfRangeErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='OutOfRangeError'] - The tag for the error.
     */
    constructor(message?: string, args?: OutOfRangeErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link OutOfRangeError}.
 */
type OutOfRangeErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link RefundExhaustedError}.
 * @typedef {Object} RefundExhaustedErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an invalid bytecode error that occurs when the gas refund limit is exhausted.
 * EVM transaction execution metadata level error
 *
 * Refund exhausted errors can occur due to:
 * - The transaction exceeding the gas refund limit.
 *
 * To debug a refund exhausted error:
 * 1. **Review Gas Usage**: Ensure that the gas usage in the contract is within the refund limits.
 * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify excessive gas usage.
 *
 * @example
 * ```typescript
 * import { RefundExhaustedError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw a RefundExhaustedError
 * } catch (error) {
 *   if (error instanceof RefundExhaustedError) {
 *     console.error(error.message);
 *     // Handle the refund exhausted error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Refund exhausted error occurred.'] - A human-readable error message.
 * @param {RefundExhaustedErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'RefundExhaustedError'} _tag - Same as name, used internally.
 * @property {'RefundExhaustedError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class RefundExhaustedError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs a RefundExhaustedError.
     * Represents an invalid bytecode error that occurs when the gas refund limit is exhausted.
     * EVM transaction execution metadata level error
     *
     * Refund exhausted errors can occur due to:
     * - The transaction exceeding the gas refund limit.
     *
     * To debug a refund exhausted error:
     * 1. **Review Gas Usage**: Ensure that the gas usage in the contract is within the refund limits.
     * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify excessive gas usage.
     *
     *
     * @param {string} [message='Refund exhausted error occurred.'] - Human-readable error message.
     * @param {RefundExhaustedErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='RefundExhaustedError'] - The tag for the error.}
     */
    constructor(message?: string, args?: RefundExhaustedErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link RefundExhaustedError}.
 */
type RefundExhaustedErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a StackOverflowError.
 * @typedef {Object} StackOverflowErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an invalid bytecode error that occurs when there is a stack overflow during execution.
 * This error is typically encountered when an operation causes the stack to exceed its limit.
 *
 * Stack overflow errors can occur due to:
 * - Excessive recursion leading to too many function calls.
 * - Bugs in smart contract logic that cause infinite loops or excessive stack usage.
 * - Incorrect management of stack operations (e.g., pushing too many items onto the stack).
 *
 * To debug a stack overflow error:
 * 1. **Review Contract Logic**: Ensure that your smart contract logic correctly handles recursion and stack operations.
 * 2. **Optimize Stack Usage**: Refactor your code to reduce stack usage, such as minimizing the depth of recursive calls.
 * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the transaction and inspect stack changes.
 * 4. **Use Other Tools**: Use other tools with tracing such as [Foundry](https://book.getfoundry.sh/forge/traces).
 * - **Ethereumjs Source**: Refer to the [source file](https://github.com/ethereumjs/ethereumjs-monorepo/blob/master/packages/evm/src/stack.ts) where this error can occur.
 *
 * @example
 * ```typescript
 * try {
 *   // Some operation that can throw a StackOverflowError
 * } catch (error) {
 *   if (error instanceof StackOverflowError) {
 *     console.error(error.message);
 *     // Handle the stack overflow error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Stack overflow error occurred.'] - A human-readable error message.
 * @param {StackOverflowErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'StackOverflowError'} _tag - Same as name, used internally.
 * @property {'StackOverflowError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class StackOverflowError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs a StackOverflowError.
     * Represents an invalid bytecode error that occurs when there is a stack overflow during execution.
     * This error is typically encountered when an operation causes the stack to exceed its limit.
     *
     * Stack overflow errors can occur due to:
     * - Excessive recursion leading to too many function calls.
     * - Bugs in smart contract logic that cause infinite loops or excessive stack usage.
     * - Incorrect management of stack operations (e.g., pushing too many items onto the stack).
     *
     * To debug a stack overflow error:
     * 1. **Review Contract Logic**: Ensure that your smart contract logic correctly handles recursion and stack operations.
     * 2. **Optimize Stack Usage**: Refactor your code to reduce stack usage, such as minimizing the depth of recursive calls.
     * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the transaction and inspect stack changes.
     * 4. **Use Other Tools**: Use other tools with tracing such as [Foundry](https://book.getfoundry.sh/forge/traces).
     * - **Ethereumjs Source**: Refer to the [source file](https://github.com/ethereumjs/ethereumjs-monorepo/blob/master/packages/evm/src/stack.ts) where this error can occur.
     *
     * @param {string} [message='Stack overflow error occurred.'] - Human-readable error message.
     * @param {StackOverflowErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='StackOverflowError'] - The tag for the error.
     */
    constructor(message?: string, args?: StackOverflowErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a StackOverflowError.
 */
type StackOverflowErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a StackUnderflowError.
 * @typedef {Object} StackUnderflowErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents a contract/bytecode error that occurs when there is a stack underflow during execution.
 * This error is typically encountered when an operation requires more stack items than are present.
 *
 * Stack underflow errors can occur due to:
 * - Incorrect management of stack operations (e.g., popping more items than available).
 * - Bugs in smart contract logic leading to unexpected stack behavior.
 * - Issues with function calls that manipulate the stack incorrectly.
 *
 * To debug a stack underflow error:
 * 1. **Review Contract Logic**: Ensure that your smart contract logic correctly handles stack operations, especially in loops and conditional branches.
 * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the transaction and inspect stack changes.
 * 3. **Use Other Tools**: Use other tools with tracing such as [Foundry](https://book.getfoundry.sh/forge/traces).
 * - **Ethereumjs Source**: Refer to the [source file](https://github.com/ethereumjs/ethereumjs-monorepo/blob/master/packages/evm/src/stack.ts) where this error can occur.
 *
 * @example
 * ```typescript
 * try {
 *   // Some operation that can throw a StackUnderflowError
 * } catch (error) {
 *   if (error instanceof StackUnderflowError) {
 *     console.error(error.message);
 *     // Handle the stack underflow error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Stack underflow error occurred.'] - A human-readable error message.
 * @param {StackUnderflowErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'StackUnderflowError'} _tag - Same as name, used internally.
 * @property {'StackUnderflowError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class StackUnderflowError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs a StackUnderflowError.
     * This error is typically encountered when an operation requires more stack items than are present.
     *
     * Stack underflow errors can occur due to:
     * - Incorrect management of stack operations (e.g., popping more items than available).
     * - Bugs in smart contract logic leading to unexpected stack behavior.
     * - Issues with function calls that manipulate the stack incorrectly.
     *
     * To debug a stack underflow error:
     * 1. **Review Contract Logic**: Ensure that your smart contract logic correctly handles stack operations, especially in loops and conditional branches.
     * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the transaction and inspect stack changes.
     * 3. **Use Other Tools**: Use other tools with tracing such as [Foundry](https://book.getfoundry.sh/forge/traces).
     * - **Ethereumjs Source**: Refer to the [source file](https://github.com/ethereumjs/ethereumjs-monorepo/blob/master/packages/evm/src/stack.ts) where this error can occur.
     *
     * @param {string} [message='Stack underflow error occurred.'] - Human-readable error message.
     * @param {StackUnderflowErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='StackUnderflowError'] - The tag for the error.
     */
    constructor(message?: string, args?: StackUnderflowErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a StackUnderflowError.
 */
type StackUnderflowErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link StaticStateChangeError}.
 * @typedef {Object} StaticStateChangeErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an invalid bytecode/contract error that occurs when a state-changing operation is attempted in a static context.
 * This error is typically encountered when a contract attempts to modify the state during a static call.
 *
 * Static state change errors can occur due to:
 * - Attempting to modify the state in a static call.
 * - Executing state-changing operations in a read-only context.
 * - Bugs in the smart contract code leading to unintended state changes.
 *
 * To debug a static state change error:
 * 1. **Review Contract Logic**: Ensure that state-changing operations are not executed in static calls or read-only contexts.
 * 2. **Check Function Modifiers**: Verify that the function modifiers and visibility settings are correctly applied to prevent state changes in static contexts.
 * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the state change is attempted in a static context.
 * 4. **Inspect Contract Code**: Manually inspect the contract code to ensure that state changes are correctly controlled and executed only in appropriate contexts.
 *
 * @example
 * ```typescript
 * import { StaticStateChangeError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw a StaticStateChangeError
 * } catch (error) {
 *   if (error instanceof StaticStateChangeError) {
 *     console.error(error.message);
 *     // Handle the static state change error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Static state change error occurred.'] - A human-readable error message.
 * @param {StaticStateChangeErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'StaticStateChangeError'} _tag - Same as name, used internally.
 * @property {'StaticStateChangeError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class StaticStateChangeError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs a StaticStateChangeError.
     * Represents an invalid bytecode/contract error that occurs when a state-changing operation is attempted in a static context.
     * This error is typically encountered when a contract attempts to modify the state during a static call.
     *
     * Static state change errors can occur due to:
     * - Attempting to modify the state in a static call.
     * - Executing state-changing operations in a read-only context.
     * - Bugs in the smart contract code leading to unintended state changes.
     *
     * To debug a static state change error:
     * 1. **Review Contract Logic**: Ensure that state-changing operations are not executed in static calls or read-only contexts.
     * 2. **Check Function Modifiers**: Verify that the function modifiers and visibility settings are correctly applied to prevent state changes in static contexts.
     * 3. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the state change is attempted in a static context.
     * 4. **Inspect Contract Code**: Manually inspect the contract code to ensure that state changes are correctly controlled and executed only in appropriate contexts.
     *
     * @param {string} [message='Static state change error occurred.'] - Human-readable error message.
     * @param {StaticStateChangeErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='StaticStateChangeError'] - The tag for the error.
     */
    constructor(message?: string, args?: StaticStateChangeErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link StaticStateChangeError}.
 */
type StaticStateChangeErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link StopError}.
 * @typedef {Object} StopErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents a contract/bytecode error that occurs when a STOP operation is executed.
 *
 * Stop errors can occur due to:
 * - The contract execution reaching a STOP opcode.
 *
 * To debug a stop error:
 * 1. **Review Contract Logic**: Ensure that the STOP opcode is used intentionally and correctly.
 * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify the STOP operation.
 *
 * @example
 * ```typescript
 * import { StopError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw a StopError
 * } catch (error) {
 *   if (error instanceof StopError) {
 *     console.error(error.message);
 *     // Handle the stop error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Stop error occurred.'] - A human-readable error message.
 * @param {StopErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'StopError'} _tag - Same as name, used internally.
 * @property {'StopError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class StopError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs a StopError.
     * Represents a contract/bytecode error that occurs when a STOP operation is executed.
     *
     * Stop errors can occur due to:
     * - The contract execution reaching a STOP opcode.
     *
     * To debug a stop error:
     * 1. **Review Contract Logic**: Ensure that the STOP opcode is used intentionally and correctly.
     * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify the STOP operation.
     *
     * @param {string} [message='Stop error occurred.'] - Human-readable error message.
     * @param {StopErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='StopError'] - The tag for the error.
     *
     */
    constructor(message?: string, args?: StopErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link StopError}.
 */
type StopErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link ValueOverflowError}.
 * @typedef {Object} ValueOverflowErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an invalid bytecode/contract error that occurs when a value overflow happens during EVM execution.
 *
 * Value overflow errors can occur due to:
 * - Arithmetic operations that exceed the maximum value limit.
 *
 * To debug a value overflow error:
 * 1. **Review Arithmetic Operations**: Ensure that arithmetic operations are correctly handling large numbers and preventing overflow.
 * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the overflow occurs.
 *
 * @example
 * ```typescript
 * import { ValueOverflowError } from '@tevm/errors'
 * try {
 *   // Some operation that can throw a ValueOverflowError
 * } catch (error) {
 *   if (error instanceof ValueOverflowError) {
 *     console.error(error.message);
 *     // Handle the value overflow error
 *   }
 * }
 * ```
 *
 * @param {string} [message='Value overflow error occurred.'] - A human-readable error message.
 * @param {ValueOverflowErrorParameters} [args={}] - Additional parameters for the BaseError.
 * @property {'ValueOverflowError'} _tag - Same as name, used internally.
 * @property {'ValueOverflowError'} name - The name of the error, used to discriminate errors.
 * @property {string} message - Human-readable error message.
 * @property {object} [meta] - Optional object containing additional information about the error.
 * @property {number} code - Error code, analogous to the code in JSON RPC error.
 * @property {string} docsPath - Path to the documentation for this error.
 * @property {string[]} [metaMessages] - Additional meta messages for more context.
 */
declare class ValueOverflowError extends ExecutionError {
    /** @type {string} */ static EVMErrorMessage: string;
    /**
     * Constructs a ValueOverflowError.
     * Represents an invalid bytecode/contract error that occurs when a value overflow happens during EVM execution.
     *
     * Value overflow errors can occur due to:
     * - Arithmetic operations that exceed the maximum value limit.
     *
     * To debug a value overflow error:
     * 1. **Review Arithmetic Operations**: Ensure that arithmetic operations are correctly handling large numbers and preventing overflow.
     * 2. **Use TEVM Tracing**: Utilize TEVM tracing to step through the contract execution and identify where the overflow occurs.
     *
     * @param {string} [message='Value overflow error occurred.'] - Human-readable error message.
     * @param {ValueOverflowErrorParameters} [args={}] - Additional parameters for the BaseError.
     * @param {string} [tag='ValueOverflowError'] - The tag for the error.
     */
    constructor(message?: string, args?: ValueOverflowErrorParameters, tag?: string);
}
/**
 * Parameters for constructing a {@link ValueOverflowError}.
 */
type ValueOverflowErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link CommonMismatchError}.
 * @typedef {Object} CommonMismatchErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the Common for a given block does not match the Common of the VM.
 *
 * Common mismatch errors can occur due to:
 * - Discrepancies between the Common configurations for a block and the VM.
 * - Attempting to use features from a different hardfork than what's configured.
 *
 * @example
 * ```typescript
 * import { CommonMismatchError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 * import { Hardfork } from '@tevm/common'
 *
 * const client = createMemoryClient({ hardfork: Hardfork.Shanghai })
 *
 * try {
 *   await client.setChain({ hardfork: Hardfork.London })
 *   // This might throw a CommonMismatchError if the operation is incompatible
 * } catch (error) {
 *   if (error instanceof CommonMismatchError) {
 *     console.error('Common mismatch:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *     // Handle the common mismatch error, possibly by updating the client configuration
 *   }
 * }
 * ```
 *
 * @extends {ExecutionError}
 */
declare class CommonMismatchError extends ExecutionError {
    /**
     * Constructs a CommonMismatchError.
     *
     * @param {string} [message='Common mismatch error occurred.'] - Human-readable error message.
     * @param {CommonMismatchErrorParameters} [args={}] - Additional parameters for the error.
     */
    constructor(message?: string, args?: CommonMismatchErrorParameters);
}
/**
 * Parameters for constructing a {@link CommonMismatchError}.
 */
type CommonMismatchErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link EipNotEnabledError}.
 * @typedef {Object} EipNotEnabledErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {ExecutionError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when an EIP (Ethereum Improvement Proposal) is not enabled.
 *
 * EIP not enabled errors can occur due to:
 * - Attempting to use features or operations that require a specific EIP which is not enabled in the VM.
 *
 * @example
 * ```typescript
 * import { EipNotEnabledError } from '@tevm/errors'
 * import { createMemoryClient } from '@tevm/memory-client'
 * import { Hardfork } from '@tevm/common'
 *
 * const client = createMemoryClient({ hardfork: Hardfork.London })
 *
 * try {
 *   // Attempt an operation that requires an EIP not enabled in London
 *   await client.call({
 *     to: '0x...',
 *     data: '0x...',
 *     // Assuming this operation requires a post-London EIP
 *   })
 * } catch (error) {
 *   if (error instanceof EipNotEnabledError) {
 *     console.error('EIP not enabled:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *     // Handle the error, possibly by updating the client to a newer hardfork
 *   }
 * }
 * ```
 *
 * @extends {ExecutionError}
 */
declare class EipNotEnabledError extends ExecutionError {
    /**
     * Constructs an EipNotEnabledError.
     *
     * @param {string} [message='EIP not enabled error occurred.'] - Human-readable error message.
     * @param {EipNotEnabledErrorParameters} [args={}] - Additional parameters for the error.
     */
    constructor(message?: string, args?: EipNotEnabledErrorParameters);
}
/**
 * Parameters for constructing a {@link EipNotEnabledError}.
 */
type EipNotEnabledErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: ExecutionError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link MisconfiguredClientError}.
 * @typedef {Object} MisconfiguredClientErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {InternalError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the Client is misconfigured.
 *
 * This error can be thrown when:
 * - Incorrect configuration parameters are provided when creating a Client.
 * - The Client is used in a way that's incompatible with its configuration.
 *
 * @example
 * ```typescript
 * import { createMemoryClient } from '@tevm/memory-client'
 * import { MisconfiguredClientError } from '@tevm/errors'
 *
 * const memoryClient = createMemoryClient({
 *   // Assume we've misconfigured something here
 * })
 *
 * try {
 *   await memoryClient.tevmCall({
 *     to: '0x...',
 *     data: '0x...',
 *   })
 * } catch (error) {
 *   if (error instanceof MisconfiguredClientError) {
 *     console.error('Client misconfiguration:', error.message)
 *     console.log('Documentation:', error.docsLink)
 *     // Attempt to recreate the client with correct configuration
 *     // or notify the user to check their client setup
 *   }
 * }
 * ```
 *
 * @extends {InternalError}
 */
declare class MisconfiguredClientError extends InternalError {
    /**
     * Constructs a MisconfiguredClientError.
     *
     * @param {string} [message='Misconfigured client error occurred.'] - Human-readable error message.
     * @param {MisconfiguredClientErrorParameters} [args={}] - Additional parameters for the error.
     */
    constructor(message?: string, args?: MisconfiguredClientErrorParameters);
}
/**
 * Parameters for constructing a {@link MisconfiguredClientError}.
 */
type MisconfiguredClientErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: InternalError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link DefensiveNullCheckError}.
 * @typedef {Object} DefensiveNullCheckErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {InternalError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when a defensive null check is tripped.
 * This error should never be thrown and indicates a bug in the Tevm VM if it is thrown.
 *
 * @example
 * ```javascript
 * import { DefensiveNullCheckError } from '@tevm/errors'
 *
 * function assertNotNull(value, message) {
 *   if (value === null || value === undefined) {
 *     throw new DefensiveNullCheckError(message)
 *   }
 *   return value
 * }
 *
 * try {
 *   const result = someFunction()
 *   assertNotNull(result, 'Result should not be null')
 * } catch (error) {
 *   if (error instanceof DefensiveNullCheckError) {
 *     console.error('Unexpected null value:', error.message)
 *     // This indicates a bug in the Tevm VM
 *     reportBugToTevmRepository(error)
 *   }
 * }
 * ```
 *
 * @extends {InternalError}
 */
declare class DefensiveNullCheckError extends InternalError {
    /**
     * Constructs a DefensiveNullCheckError.
     *
     * @param {string} [message] - Human-readable error message.
     * @param {DefensiveNullCheckErrorParameters} [args] - Additional parameters for the error.
     */
    constructor(message?: string, args?: DefensiveNullCheckErrorParameters);
}
/**
 * Parameters for constructing a {@link DefensiveNullCheckError}.
 */
type DefensiveNullCheckErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: InternalError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing a {@link UnreachableCodeError}.
 * @typedef {Object} UnreachableCodeErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {InternalError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when unreachable code is executed.
 * This error always indicates a bug in the Tevm VM.
 *
 * @example
 * ```javascript
 * import { UnreachableCodeError } from '@tevm/errors'
 *
 * function assertUnreachable(x) {
 *   throw new UnreachableCodeError(x, 'Unreachable code executed')
 * }
 *
 * function getArea(shape) {
 *   switch (shape) {
 *     case 'circle':
 *       return Math.PI * Math.pow(radius, 2)
 *     case 'square':
 *       return side * side
 *     default:
 *       return assertUnreachable(shape)
 *   }
 * }
 *
 * try {
 *   getArea('triangle') // This should be unreachable
 * } catch (error) {
 *   if (error instanceof UnreachableCodeError) {
 *     console.error('Unreachable code executed:', error.message)
 *     console.log('Unreachable value:', error.value)
 *     // This indicates a bug in the Tevm VM
 *     reportBugToTevmRepository(error)
 *   }
 * }
 * ```
 *
 * @extends {InternalError}
 */
declare class UnreachableCodeError extends InternalError {
    /**
     * Constructs an UnreachableCodeError.
     *
     * @param {*} value - The value that should be unreachable.
     * @param {string} [message] - Human-readable error message.
     * @param {UnreachableCodeErrorParameters} [args] - Additional parameters for the error.
     */
    constructor(value: any, message?: string, args?: UnreachableCodeErrorParameters);
    /**
     * The value that should be unreachable.
     * @type {*}
     */
    value: any;
}
/**
 * Parameters for constructing a {@link UnreachableCodeError}.
 */
type UnreachableCodeErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: InternalError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * Parameters for constructing an {@link InvalidBytesSizeError}.
 * @typedef {Object} InvalidBytesSizeErrorParameters
 * @property {string} [docsBaseUrl] - Base URL for the documentation.
 * @property {string} [docsPath] - Path to the documentation.
 * @property {string} [docsSlug] - Slug for the documentation.
 * @property {string[]} [metaMessages] - Additional meta messages.
 * @property {InternalError|import('@ethereumjs/evm').EVMError} [cause] - The cause of the error.
 * @property {string} [details] - Details of the error.
 * @property {object} [meta] - Optional object containing additional information about the error.
 */
/**
 * Represents an error that occurs when the size of the bytes does not match the expected size.
 *
 * @example
 * ```javascript
 * import { InvalidBytesSizeError } from '@tevm/errors'
 * import { hexToBytes } from '@tevm/utils'
 *
 * function requireBytes32(value) {
 *   const bytes = hexToBytes(value)
 *   if (bytes.length !== 32) {
 *     throw new InvalidBytesSizeError(bytes.length, 32)
 *   }
 *   return bytes
 * }
 *
 * try {
 *   requireBytes32('0x1234') // This will throw an InvalidBytesSizeError
 * } catch (error) {
 *   if (error instanceof InvalidBytesSizeError) {
 *     console.error(`Invalid bytes size: ${error.message}`)
 *     console.log(`Actual size: ${error.size}, Expected size: ${error.expectedSize}`)
 *   }
 * }
 * ```
 *
 * @extends {InternalError}
 */
declare class InvalidBytesSizeError extends InternalError {
    /**
     * Constructs an InvalidBytesSizeError.
     *
     * @param {number} size - The actual size of the bytes.
     * @param {number} expectedSize - The expected size of the bytes.
     * @param {string} [message] - Human-readable error message.
     * @param {InvalidBytesSizeErrorParameters} [args] - Additional parameters for the error.
     */
    constructor(size: number, expectedSize: number, message?: string, args?: InvalidBytesSizeErrorParameters);
    /**
     * The actual size of the bytes.
     * @type {number}
     */
    size: number;
    /**
     * The expected size of the bytes.
     * @type {number}
     */
    expectedSize: number;
}
/**
 * Parameters for constructing an {@link InvalidBytesSizeError}.
 */
type InvalidBytesSizeErrorParameters = {
    /**
     * - Base URL for the documentation.
     */
    docsBaseUrl?: string;
    /**
     * - Path to the documentation.
     */
    docsPath?: string;
    /**
     * - Slug for the documentation.
     */
    docsSlug?: string;
    /**
     * - Additional meta messages.
     */
    metaMessages?: string[];
    /**
     * - The cause of the error.
     */
    cause?: InternalError | _ethereumjs_evm.EVMError;
    /**
     * - Details of the error.
     */
    details?: string;
    /**
     * - Optional object containing additional information about the error.
     */
    meta?: object;
};

/**
 * @module requestErrors
 * @description This module exports various RPC-related errors from the 'viem' library.
 */

/**
 * Represents the possible error codes for RPC errors.
 */
type RpcErrorCode = -1 | -32700 | -32600 | -32601 | -32602 | -32603 | -32000 | -32001 | -32002 | -32003 | -32004 | -32005 | -32006 | -32042;

/**
 * @type {Record<import('./requestErrors.js').RpcErrorCode, string>}
 */
declare const rpcErrorCodeToMessage: Record<RpcErrorCode, string>;

export { AccountLockedError, type AccountLockedErrorParameters, AccountNotFoundError, AuthCallUnsetError, type AuthCallUnsetErrorParameters, BLS12381FpNotInFieldError, type BLS12381FpNotInFieldErrorParameters, BLS12381InputEmptyError, type BLS12381InputEmptyErrorParameters, BLS12381InvalidInputLengthError, type BLS12381InvalidInputLengthErrorParameters, BLS12381PointNotOnCurveError, type BLS12381PointNotOnCurveErrorParameters, BaseError, type BaseErrorParameters, BlockGasLimitExceededError, type BlockGasLimitExceededErrorParameters, ChainIdMismatchError, type ChainIdMismatchErrorParameters, CodeSizeExceedsMaximumError, type CodeSizeExceedsMaximumErrorParameters, CodeStoreOutOfGasError, type CodeStoreOutOfGasErrorParameters, CommonMismatchError, type CommonMismatchErrorParameters, ContractExecutionFailedError, type ContractExecutionFailedErrorParameters, CreateCollisionError, type CreateCollisionErrorParameters, DecodeFunctionDataError, DefensiveNullCheckError, type DefensiveNullCheckErrorParameters, EipNotEnabledError, type EipNotEnabledErrorParameters, EncodeFunctionReturnDataError, EvmRevertError, type EvmRevertErrorParameters, ExecutionError, type ExecutionErrorParameters, ForkError, type ForkErrorParameters, GasLimitExceededError, type GasLimitExceededErrorParameters, InitcodeSizeViolationError, type InitcodeSizeViolationErrorParameters, InsufficientBalanceError, type InsufficientBalanceErrorParameters, InsufficientFundsError, type InsufficientFundsErrorParameters, InsufficientPermissionsError, type InsufficientPermissionsErrorParameters, InternalError, type InternalErrorParameters, InternalEvmError, type InternalEvmErrorParameters, InvalidAbiError, type InvalidAbiErrorParameters, InvalidAddToBlockchainError, type InvalidAddToBlockchainErrorParameters, InvalidAddToMempoolError, type InvalidAddToMempoolErrorParameters, InvalidAddressError, type InvalidAddressErrorParameters, InvalidArgsError, type InvalidArgsErrorParameters, InvalidBalanceError, type InvalidBalanceErrorParameters, InvalidBeginSubError, type InvalidBeginSubErrorParameters, InvalidBlobVersionedHashesError, type InvalidBlobVersionedHashesErrorParameters, InvalidBlockError, type InvalidBlockErrorParameters, InvalidBytecodeError, type InvalidBytecodeErrorParameters, InvalidBytecodeResultError, type InvalidBytecodeResultErrorParameters, InvalidBytesSizeError, type InvalidBytesSizeErrorParameters, InvalidCallerError, type InvalidCallerErrorParameters, InvalidCommitmentError, type InvalidCommitmentErrorParameters, InvalidDataError, type InvalidDataErrorParameters, InvalidDeployedBytecodeError, type InvalidDeployedBytecodeErrorParameters, InvalidDepthError, type InvalidDepthErrorParameters, InvalidEofFormatError, type InvalidEofFormatErrorParameters, InvalidFunctionNameError, type InvalidFunctionNameErrorParameters, InvalidGasLimitError, type InvalidGasLimitErrorParameters, InvalidGasPriceError, type InvalidGasPriceErrorParameters, InvalidGasRefundError, type InvalidGasRefundErrorParameters, InvalidInputLengthError, type InvalidInputLengthErrorParameters, InvalidJumpError, type InvalidJumpErrorParameters, InvalidJumpSubError, type InvalidJumpSubErrorParameters, InvalidKzgInputsError, type InvalidKzgInputsErrorParameters, InvalidMaxFeePerGasError, type InvalidMaxFeePerGasErrorParameters, InvalidMaxPriorityFeePerGasError, type InvalidMaxPriorityFeePerGasErrorParameters, InvalidNonceError, type InvalidNonceErrorParameters, InvalidOpcodeError, type InvalidOpcodeErrorParameters, InvalidOriginError, type InvalidOriginErrorParameters, InvalidParamsError, type InvalidParamsErrorParameters, InvalidProofError, type InvalidProofErrorParameters, InvalidRequestError, type InvalidRequestErrorParameters, InvalidReturnSubError, type InvalidReturnSubErrorParameters, InvalidSaltError, type InvalidSaltErrorParameters, InvalidSelfdestructError, type InvalidSelfdestructErrorParameters, InvalidSignatureError, type InvalidSignatureErrorParameters, InvalidSkipBalanceError, type InvalidSkipBalanceErrorParameters, InvalidStorageRootError, type InvalidStorageRootErrorParameters, InvalidToError, type InvalidToErrorParameters, InvalidTransactionError, type InvalidTransactionErrorParameters, InvalidUrlError, type InvalidUrlErrorParameters, InvalidValueError, type InvalidValueErrorParameters, LimitExceededError, type LimitExceededErrorParameters, MethodNotFoundError, type MethodNotFoundErrorParameters, MethodNotSupportedError, type MethodNotSupportedErrorParameters, MisconfiguredClientError, type MisconfiguredClientErrorParameters, NoForkTransportSetError, type NoForkTransportSetErrorParameters, NonceAlreadyUsedError, type NonceAlreadyUsedErrorParameters, NonceTooHighError, type NonceTooHighErrorParameters, NonceTooLowError, type NonceTooLowErrorParameters, OutOfGasError, type OutOfGasErrorParameters, OutOfRangeError, type OutOfRangeErrorParameters, ParseError, type ParseErrorParameters, PendingTransactionTimeoutError, type PendingTransactionTimeoutErrorParameters, RateLimitExceededError, type RateLimitExceededErrorParameters, RefundExhaustedError, type RefundExhaustedErrorParameters, ResourceNotFoundError, type ResourceNotFoundErrorParameters, ResourceUnavailableError, type ResourceUnavailableErrorParameters, RevertError, type RevertErrorParameters, type RpcErrorCode, StackOverflowError, type StackOverflowErrorParameters, StackUnderflowError, type StackUnderflowErrorParameters, StaticStateChangeError, type StaticStateChangeErrorParameters, StopError, type StopErrorParameters, TransactionRejectedError, type TransactionRejectedErrorParameters, TransactionTooLargeError, type TransactionTooLargeErrorParameters, TransactionUnderpricedError, type TransactionUnderpricedErrorParameters, UnknownBlockError, type UnknownBlockErrorParameters, UnreachableCodeError, type UnreachableCodeErrorParameters, UnsupportedChainError, type UnsupportedChainErrorParameters, ValueOverflowError, type ValueOverflowErrorParameters, rpcErrorCodeToMessage };
